<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_AddUser
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_AddUser extends Moc10_Form
{

    /**
     * Form template
     * @var string
     */
    protected $_template = null;

    /**
     * $_POST fields
     * @var array
     */
    protected $_postFields = array('plugin' => null,
                                   'fname' => null,
                                   'lname' => null,
                                   'email1' => null,
                                   'email2' => null,
                                   'username' => null,
                                   'password1' => null,
                                   'password2' => null,
                                   'access' => null,
                                   'allowed' => null,
                                   'send_creds' => null,
                                   'user_id' => 0);

    /**
     * Initialization method for the add user form.
     *
     * @param  array $post
     * @return void
     */
    public function init($post = null)
    {

        $lang = new Phire_Language();

        $this->_setFields($post);
        $this->_setTemplates();

        $this->setAttributes('id', 'addUserForm');
        $this->setAttributes('onsubmit', "return addUserFrm.userValidate();");

        // Create the 'fname' form element.
        $fname = new Moc10_Form_Element('text', 'fname', $this->_postFields['fname']);
        $fname->setLabel($lang->__('First Name:'));
        $fname->setAttributes('size', '40');
        $fname->setRequired(true);

        // Create the 'lname' form element.
        $lname = new Moc10_Form_Element('text', 'lname', $this->_postFields['lname']);
        $lname->setLabel($lang->__('Last Name:'));
        $lname->setAttributes('size', '40');
        $lname->setRequired(true);

        // Create the 'email1' form element.
        $email1 = new Moc10_Form_Element('text', 'email1', $this->_postFields['email1']);
        $email1->setLabel($lang->__('Email:'));
        $email1->addValidator('Email');
        $email1->setAttributes('size', '40');
        $email1->setRequired(true);

        // Create the 'email2' form element.
        $email2 = new Moc10_Form_Element('text', 'email2', $this->_postFields['email2']);
        $email2->setLabel($lang->__('Confirm Email:'));
        $email2->addValidator('Email');
        $email2->addValidator('Equal', true, $this->_postFields['email1'], $lang->__('The emails do not match.'));
        $email2->setAttributes('size', '40');
        $email2->setRequired(true);

        // Create the 'username' form element.
        $username = new Moc10_Form_Element('text', 'username', $this->_postFields['username']);
        $username->setLabel($lang->__('Username:'));
        $username->addValidator('AlphaNum');
        $username->addValidator('LengthGT', true, 3);
        $username->setAttributes('size', '40');
        $username->setAttributes('autocomplete', 'off');
        $username->setAttributes('onkeyup', "xmlhttp.getRequest('../core/process/check.username.php?username=' + this.value, checkUsername); return false;");
        $username->setRequired(true);

        // If the form has been submitted, validate the username.
        if (!is_null($this->_postFields['username'])) {
            $dupe_user = new Phire_Table_Users();
            $dupe_user->findBy('username', $this->_postFields['username']);
            if (isset($dupe_user->user_id)) {
                $username->addValidator('NotEqual', true, $dupe_user->username, $lang->__('That username already exists.'));
            }
        }

        // Create the 'password1' form element.
        $password1 = new Moc10_Form_Element('password', 'password1', $this->_postFields['password1']);
        $password1->setLabel($lang->__('Password:'));
        $password1->addValidator('LengthGT', true, 5);
        $password1->setAttributes('size', '20');
        $password1->setRequired(true);

        // Create the 'password2' form element.
        $password2 = new Moc10_Form_Element('password', 'password2', $this->_postFields['password2']);
        $password2->setLabel($lang->__('Re-type Password:'));
        $password2->addValidator('LengthGT', true, 5);
        $password2->addValidator('Equal', true, $this->_postFields['password1'], $lang->__('The passwords do not match.'));
        $password2->setAttributes('size', '20');
        $password2->setRequired(true);

        // Create the 'access' form element.
        $access = new Moc10_Form_Element_Select('access', array('Blocked' => $lang->__('Blocked'), 'Restricted' => $lang->__('Restricted'), 'Basic' => $lang->__('Basic'), 'Full' => $lang->__('Full'), 'Admin' => $lang->__('Admin')), $this->_postFields['access']);
        $access->setLabel($lang->__('Access:'));
        $access->setRequired(true);

        $all_sites = new Phire_Table_Sites();
        $all_sites->findAll();
        $all_sites_array = array();
        foreach ($all_sites->rows as $ste) {
            $all_sites_array[$ste->site_id] = $ste->site_domain;
        }

        // Create the 'allowed' form element.
        $allowed = new Moc10_Form_Element_Checkbox('allowed', $all_sites_array, $this->_postFields['allowed']);
        $allowed->setLabel($lang->__('Allowed Sites:'));
        $allowed->setRequired(true);

        // Create the 'send_creds' form element.
        $send_creds = new Moc10_Form_Element_Checkbox('send_creds', array('send_creds' => $lang->__('Send credentials to user?')), $this->_postFields['send_creds']);

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $lang->__('SAVE'));
        $submit->setAttributes('class', 'submitBtn');
        $submit->setAttributes('style', 'float: left;');

        // Set the form template and add the form element objects to the form.
        $this->setTemplate($this->_template);
        $this->addElements(array($fname, $lname, $email1, $email2, $username, $password1, $password2, $access, $allowed, $send_creds, $submit));

    }

    /**
     * Method to save the user data.
     *
     * @return void
     */
    public function saveData()
    {

        $lang = new Phire_Language();

        // Determine if user verification is required and if user password encoding is activated.
        $config = new Phire_Table_Config();
        $verified = ($config->settings['user_verification'] == 'Off') ? 'Yes' : 'No';
        if ($config->settings['user_password_encoding'] != 'Off') {
            $password = ($config->settings['user_password_encoding'] == 'SHA1') ? sha1($this->_postFields['password1']) : md5($this->_postFields['password1']);
        } else {
            $password = $this->_postFields['password1'];
        }
        $org_password = $this->_postFields['password1'];

        // Initialize and save the new user.
        $userFields = array('fname' => $this->_postFields['fname'],
                            'lname' => $this->_postFields['lname'],
                            'email' => $this->_postFields['email1'],
                            'username' => $this->_postFields['username'],
                            'password' => $password,
                            'verified' => $verified,
                            'access' => $this->_postFields['access'],
                            'allowed_sites' => implode('|', $this->_postFields['allowed']),
                            'last_login' => '0000-00-00 00:00:00',
                            'last_login_from' => '',
                            'last_ip' => '',
                            'failed_login_attempts' => 0);

        $user = new Phire_Table_Users($userFields);
        $user->save();

        // If user verification is required, build and send the verification email.
        if ($verified == 'No') {

            $rcpt = array(array('name' => $this->_postFields['fname'] . ' ' . $this->_postFields['lname'],
                                'email' => $user->email,
                                'username' => $user->username,
                                'password' => $org_password,
                                'verify_link' => 'http://' . $_SERVER['HTTP_HOST'] . BASE_PATH . '/user/verify/' . $user->user_id . '/' . sha1($user->email),
                                'login_link' => 'http://' . $_SERVER['HTTP_HOST'] . BASE_PATH . SYS_PATH . '/'));

            $message = "[{name}],\n\n" . $lang->__('Your user account for the Phire CMS has been created. Your credentials for the Phire CMS are:') . "\n\n" . $lang->__('Username:') . " [{username}]\n" . $lang->__('Password:') . " [{password}]\n\n" . $lang->__('In order to access the account you must verify your email address. Please click on the link below to verify your email address:') . "\n[{verify_link}]\n\n" . $lang->__('Once successfully verified, you can then log in here:') . "\n[{login_link}]\n\n" . $lang->__('Thank You,') . "\n\n" . $lang->__('The Phire CMS Team') . "\n\n";

            $noreply = 'noreply@' . ((stripos($_SERVER['HTTP_HOST'], 'www.') !== false) ? str_replace('www.', '', $_SERVER['HTTP_HOST']) : $_SERVER['HTTP_HOST']);

            $mail = new Moc10_Mail($rcpt, null, $lang->__('Phire CMS User Account Created - Verification Required'));
            $mail->setHeaders(array('From' => array($noreply, $noreply),
                                    'Reply-To' => array($noreply, $noreply)));

            $mail->setText($message);
            $mail->init();
            $mail->send();

        }

        // Else, if 'send credentials' was checked, build and send the credentials email.
        if (isset($this->_postFields['send_creds'])) {

            $rcpt = array(array('name' => $this->_postFields['fname'] . ' ' . $this->_postFields['lname'],
                                'email' => $user->email,
                                'username' => $user->username,
                                'password' => $org_password,
                                'login_link' => 'http://' . $_SERVER['HTTP_HOST'] . BASE_PATH . SYS_PATH . '/'));

            $message = "[{name}],\n\n" . $lang->__('Your user account for the Phire CMS has been created. Your credentials for the Phire CMS are:') . "\n\n" . $lang->__('Username:') . " [{username}]\n" . $lang->__('Password:') . " [{password}]\n\n" . $lang->__('You can log in here:') . "\n[{login_link}]\n\n" . $lang->__('Thank You,') . "\n\n" . $lang->__('The Phire CMS Team') . "\n\n";

            $noreply = 'noreply@' . ((stripos($_SERVER['HTTP_HOST'], 'www.') !== false) ? str_replace('www.', '', $_SERVER['HTTP_HOST']) : $_SERVER['HTTP_HOST']);

            $mail = new Moc10_Mail($rcpt, null, $lang->__('Phire CMS User Account Created'));
            $mail->setHeaders(array('From' => array($noreply, $noreply),
                                    'Reply-To' => array($noreply, $noreply)));

            $mail->setText($message);
            $mail->init();
            $mail->send();

        }

    }

    /**
     * Method to set the post fields.
     *
     * @param  array $post
     * @return void
     */
    protected function _setFields($post = null)
    {

        if (!is_null($post)) {
            foreach ($post as $key => $value) {
                if (array_key_exists($key, $this->_postFields)) {
                    $this->_postFields[$key] = (isset($post[$key])) ? $post[$key] : null;
                }
            }
        }

    }

    /**
     * Method to set the form templates.
     *
     * @return void
     */
    protected function _setTemplates()
    {

        $lang = new Phire_Language();
        $back = $lang->__('Back');
        $blue = $lang->__('Blue fields are required.');
        $user_info = $lang->__('User Information');
        $user_pass = $lang->__('Username & Password');
        $user_4chars = $lang->__('Username must be alphanumeric and at least 4 characters in length.');
        $pass_6chars = $lang->__('Password must be at least 6 characters in length.');
        $chk_all = $lang->__('Check All');
        $unchk_all = $lang->__('Uncheck All');
        $inv = $lang->__('Inverse');
        $access_settings = $lang->__('Access Settings');
        $sending = wordwrap($lang->__("Sending the credentials to the user requires both the server's PHP mail function and SMTP mail agent to be configured correctly."), 80, "<br />\n");
        $cancel = $lang->__('CANCEL');

        if (!is_null($this->_postFields['plugin'])) {
            $plugin = "<input type=\"hidden\" name=\"plugin\" value=\"{$this->_postFields['plugin']}\" />";
            $plg_lnk = BASE_PATH . CONTENT_PATH . "/extensions/plugins/{$this->_postFields['plugin']}/?sys_path=" . BASE_PATH . SYS_PATH;
            $plg_cancel = "&plugin={$this->_postFields['plugin']}";
        } else {
            $plugin = null;
            $plg_lnk = './users.php';
            $plg_cancel = null;
        }

        // Define the main form template.
        $this->_template = <<<FORMTEMP
            <style type="text/css">
                .radioPad {
                    float: left;
                    margin: 0;
                    padding: 0 18px 0 4px;
                }
                .checkBoxArea {
                    width: 280px;
                }
                .checkBox {
                    clear: both;
                    float: left;
                }
                .checkPad {
                    display: block;
                    margin: 9px 0 0 5px;
                    float: left;
                }
            </style>
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="{$plg_lnk}">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader">
                    <td class="grayHeader">
                        <strong style="padding-left: 25px;">{$user_info}</strong>
                    </td>
                </tr>
                <tr>
                    <td style="padding: 15px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td class="textTopRight">
                                    &nbsp;
                                </td>
                                <td>
                                    <h4>{$blue}</h4>
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{fname_label}]
                                </td>
                                <td>
                                    [{fname}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{lname_label}]
                                </td>
                                <td>
                                    [{lname}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{email1_label}]
                                </td>
                                <td>
                                    [{email1}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{email2_label}]<br /><br /><br />
                                </td>
                                <td>
                                    [{email2}]<br /><br /><br />
                                </td>
                            </tr>
                            <tr style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                <td colspan="2" style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                    <strong style="font-size: 0.85em;">{$user_pass}</strong>
                                </td>
                            </tr>
                            <tr>
                                <td>
                                    &nbsp;<br />
                                </td>
                                <td>
                                    <br /><em>{$user_4chars}</em><br />
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{username_label}]
                                </td>
                                <td>
                                    [{username}]
                                    <div id="usernameDiv">
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td>
                                    <em>{$pass_6chars}</em><br />
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{password1_label}]
                                </td>
                                <td>
                                    [{password1}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{password2_label}]<br /><br /><br />
                                </td>
                                <td>
                                    [{password2}]<br /><br /><br />
                                </td>
                            </tr>
                            <tr style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                <td colspan="2" style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                    <strong style="font-size: 0.85em;">{$access_settings}</strong>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    <br />
                                    [{access_label}]
                                </td>
                                <td>
                                    <br />
                                    [{access}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight" style="padding: 9px 5px;">
                                    [{allowed_label}]<br />
                                    <a class="smallOrangeLink" href="#" onclick="addUserFrm.checkAll('allowed'); return false;">[ {$chk_all} ]</a><br />
                                    <a class="smallOrangeLink" href="#" onclick="addUserFrm.uncheckAll('allowed'); return false;">[ {$unchk_all} ]</a><br />
                                    <a class="smallOrangeLink" href="#" onclick="addUserFrm.checkInverse('allowed'); return false;">[ {$inv} ]</a><br />
                                </td>
                                <td style="vertical-align: top;">
                                    [{allowed}]
                                </td>
                            </tr>
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td>
                                    [{send_creds}]
                                    <em style="font-size: 0.85em;">{$sending}</em>
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    &nbsp;
                                </td>
                            </tr>
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td>
                                    [{submit}] <a style="margin: 0 0 0 10px; padding-top: 6px; height: 19px; font-size: 0.825em; float: left;" class="submitGrayBtn" href="../core/process/add.user.php?action=cancel{$plg_cancel}">{$cancel}</a> {$plugin}
                                </td>
                            </tr>
                        </table>
                        <script type="text/javascript">
                            addUserFormInit();
                            addUserFrm.fo.fname.focus();
                            var xmlhttp = new JaxXmlHttp();
                        </script>
                    </td>
                </tr>
            </table>
FORMTEMP;

    }

}
