<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_EditFile
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_EditFile extends Moc10_Form
{

    /**
     * Form templates
     * @var array
     */
    protected $_templates = array('main' => null, 'mobile' => null);

    /**
     * $_POST fields
     * @var array
     */
    protected $_postFields = array('plugin' => null,
                                   'site_id' => null,
                                   'section_id' => null,
                                   'file_name' => null,
                                   'file_title' => null,
                                   'file_desc' => null,
                                   'file_updated' => null,
                                   'current_file_name' => null,
                                   'mobile' => null,
                                   'file_id' => 0);

    /**
     * Initialization method for the edit file form.
     *
     * @param  array $post
     * @param  string $fle_nme
     * @return void
     */
    public function init($post = null, $fle_nme = null)
    {

        $lang = new Phire_Language();

        $this->_setFields($post, $fle_nme);
        $this->_setTemplates();

        $this->setAttributes('id', 'editFileForm');
        $this->setAttributes('enctype', 'multipart/form-data');

        // Get sections.
        $sects = new Phire_Table_Sections();
        $sects->findAll('section_id ASC', 'site_id', $this->_postFields['site_id']);
        $sectAry = array('0' => '(' . $lang->__('None') . ')');
        if (isset($sects->rows[0])) {
            foreach ($sects->rows as $sect) {
                $sectAry[$sect->section_id] = $sect->section_title;
            }
        }

        // Create the 'section_id' form element.
        $section_id = new Moc10_Form_Element_Select('section_id', $sectAry, $this->_postFields['section_id']);
        $section_id->setLabel($lang->__('Section:'));

        $brws = new Moc10_Session_Browser();
        $fileClass = ($brws->browser == 'MSIE') ? 'fileInputIE' : 'fileInput';

        // Create the 'file_name' form element.
        $file_name = new Moc10_Form_Element('file', 'file_name', null);
        $file_name->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Replace?') : $lang->__('Replace Current File?')));
        $file_name->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '25' : '35'));
        $file_name->setAttributes('class', $fileClass);

        // Create the 'file_title' form element.
        $file_title = new Moc10_Form_Element('text', 'file_title', $this->_postFields['file_title']);
        $file_title->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Title:') : $lang->__('File Title:')));
        $file_title->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '25' : '35'));

        // Create the 'file_desc' form element.
        $file_desc = new Moc10_Form_Element('text', 'file_desc', $this->_postFields['file_desc']);
        $file_desc->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Description:') : $lang->__('File Description:')));
        $file_desc->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '25' : '80'));

        // Create the 'current_file_name' form element.
        $current_file_name = new Moc10_Form_Element('hidden', 'current_file_name', $this->_postFields['file_name']);

        // Create the 'file_id' form element.
        $file_id = new Moc10_Form_Element('hidden', 'file_id', $this->_postFields['file_id']);

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $lang->__('SAVE'));
        $submit->setAttributes('style', 'float: right;');

        // Set whether it's a mobile form template or not.
        if (!is_null($this->_postFields['mobile'])) {
            $sess = Moc10_Session::getInstance();
            $site_id = new Moc10_Form_Element('hidden', 'site_id', $sess->cur_site_id);
            $submit->setAttributes('class', 'submitBtn');
            $this->setTemplate($this->_templates['mobile']);
        } else {
            $site_id = new Moc10_Form_Element_Select('site_id', Phire_Sites::getAllowedSites(), $this->_postFields['site_id']);
            $site_id->setLabel($lang->__('Site:'));
            $submit->setAttributes('class', 'submitBtn');
            $site_id->setAttributes('onchange', "xmlhttp.getRequest('../core/process/check.section.php?site_id=' + this.value, editFileFrm.changeSection); return false;");
            $this->setTemplate($this->_templates['main']);
        }

        // Add the form element objects to the form.
        $this->addElements(array($site_id, $section_id, $file_name, $file_title, $file_desc, $submit, $current_file_name, $file_id));

    }

    /**
     * Method to set the form templates.
     *
     * @return void
     */
    protected function _setTemplates()
    {

        $lang = new Phire_Language();
        $last = $lang->__('Last Updated:');
        $back = $lang->__('Back');
        $donot_wrap = wordwrap($lang->__('Once you click save, DO NOT leave the page until the files have finished processing.'), 80, "<br />");
        $donot = $lang->__('Once you click save, DO NOT leave the page until the files have finished processing.');
        $cancel = $lang->__('CANCEL');

        if (!is_null($this->_postFields['file_updated'])) {
            $last_update = ($this->_postFields['file_updated'] != '0000-00-00 00:00:00') ? '<strong>' . $last . '</strong> ' . date('l, M j, Y g:i A', strtotime($this->_postFields['file_updated'])) : '<strong>Last Updated:</strong> Never';
            $dateStamp = "<span style=\"padding: 0 15px 0 15px;\">" . $last_update . "</span>";
        } else {
            $dateStamp = '&nbsp;';
        }

        $site = new Phire_Table_Sites();
        $site->getSite($this->_postFields['site_id']);
        $domain = 'http://' . $site->site_domain . BASE_PATH . CONTENT_PATH . '/assets/files/';

        $size = null;
        $fle = new Moc10_File($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/files/' . $this->_postFields['current_file_name']);

        if ($fle->size < 1000) {
            $size = '< 1 KB';
        } else if (($fle->size >= 1000) && ($fle->size < 1000000)) {
            $size = round(($fle->size / 1000), 1) . ' KB';
        } else if ($fle->size >= 1000000) {
            $size = round(($fle->size / 1000000), 2) . ' MB';
        } else {
            $size = $fle->size;
        }

        if (!is_null($this->_postFields['plugin'])) {
            $plugin = "<input type=\"hidden\" name=\"plugin\" value=\"{$this->_postFields['plugin']}\" />";
            $plg_lnk = BASE_PATH . CONTENT_PATH . "/extensions/plugins/{$this->_postFields['plugin']}/?sys_path=" . BASE_PATH . SYS_PATH;
            $plg_cancel = "&plugin={$this->_postFields['plugin']}";
        } else {
            $plugin = null;
            $plg_lnk = './files.php';
            $plg_cancel = null;
        }

        // Define the main form template.
        $this->_templates['main'] = <<<FORMTEMP
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="{$plg_lnk}">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader">
                    <td class="grayHeader">
                        {$dateStamp}
                    </td>
                </tr>
                <tr>
                    <td style="padding: 15px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td colspan="4" class="textRight">
                                    [{site_id_label}]
                                    [{site_id}]
                                    <span style="padding: 0 10px 0 10px;"> </span>
                                    [{section_id_label}]
                                    <span id="sectionDiv">
                                        [{section_id}]
                                    </span>
                                </td>
                            </tr>
                            <tr>
                                <td style="text-align: center;">
                                    <strong>Download</strong>
                                </td>
                                <td>
                                    [{file_name_label}]
                                </td>
                                <td>
                                    [{file_title_label}]
                                </td>
                                <td>
                                    [{file_desc_label}]
                                </td>
                            </tr>
                            <tr>
                                <td style="vertical-align: top; text-align: center;">
                                    <a class="downloadLink" href="{$domain}{$this->_postFields['file_name']}" title="Download {$this->_postFields['file_name']}"></a>
                                </td>
                                <td style="vertical-align: top;">
                                    [{file_name}]
                                </td>
                                <td style="vertical-align: top;">
                                    [{file_title}]
                                </td>
                                <td style="vertical-align: top;">
                                    [{file_desc}]
                                </td>
                            </tr>
                            <tr>
                                <td style="vertical-align: top; text-align: center;">
                                    <span style="font-size: 0.8em;">{$size}</span>
                                </td>
                                <td colspan="3">
                                    <strong style="float: left; color: #f00;">{$donot_wrap}</strong><a style="margin: 0 0 0 10px; padding-top: 6px; height: 19px; font-size: 0.825em; float: right;" class="submitGrayBtn" href="../core/process/edit.file.php?action=cancel{$plg_cancel}">{$cancel}</a> [{submit}] [{file_id}] [{current_file_name}] {$plugin}
                                </td>
                            </tr>
                        </table>
                        <script type="text/javascript">
                            editFileFormInit();
                            var xmlhttp = new JaxXmlHttp();
                        </script>
                    </td>
                </tr>
            </table>
FORMTEMP;

        $mobile = (!is_null($this->_postFields['mobile'])) ? "<input type=\"hidden\" name=\"mobile\" value=\"true\" />" : null;

        // Define the mobile form template.
        $this->_templates['mobile'] = <<<FORMTEMP
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="./files.php"> Back</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader" style="height; 16px;">
                    <td class="grayHeader" style="height; 16px;">
                        {$dateStamp}
                    </td>
                </tr>
                <tr>
                    <td style="padding: 5px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td class="textRight">
                                    [{section_id_label}]
                                </td>
                                <td>
                                    [{section_id}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{file_name_label}]
                                </td>
                                <td id="fileNameTD" style="vertical-align: top;">
                                    [{file_name}]<br />
                                    <a class="downloadLink" style="margin: 0;" href="{$domain}{$this->_postFields['file_name']}" title="Download {$this->_postFields['file_name']}"></a><br />
                                    <span style="font-size: 0.8em;">{$size}</span>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{file_title_label}]
                                </td>
                                <td id="fileTitleTD" style="vertical-align: top;">
                                    [{file_title}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{file_desc_label}]
                                </td>
                                <td id="fileDescTD" style="vertical-align: top;">
                                    [{file_desc}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    <strong style="color: #f00;">{$donot}</strong><br /><br />
                                    <a style="float: right; margin: 0 0 0 5px; padding: 2px 3px 4px 3px; height: 10px; font-size: 0.9em;" class="submitBtnGray" href="../../core/process/edit.file.php?action=cancel&mobile=true">{$cancel}</a> [{submit}] {$mobile} [{site_id}] [{current_file_name}] [{file_id}]
                                </td>
                            </tr>
                        </table>
                    </td>
                </tr>
            </table>
FORMTEMP;

    }

    /**
     * Method to set the post fields.
     *
     * @param  array $post
     * @param  string $fle_nme
     * @return void
     */
    protected function _setFields($post = null, $fle_nme = null)
    {

        if (!is_null($post)) {
            if ((!$_POST) && isset($post['file_id']) && ($post['file_id'] != 0)) {

                $file = new Phire_Table_Files();
                $file->findById($post['file_id']);

                $this->_postFields['site_id'] = $file->site_id;
                $this->_postFields['section_id'] = $file->section_id;
                $this->_postFields['file_name'] = $file->file_name;
                $this->_postFields['file_title'] = (string)Moc10_String::setString($file->file_title)->strip()->html();
                $this->_postFields['file_desc'] = (string)Moc10_String::setString($file->file_desc)->strip()->html();
                $this->_postFields['file_updated'] = $file->file_updated;
                $this->_postFields['current_file_name'] = $file->file_name;
                $this->_postFields['plugin'] = (isset($post['plugin'])) ? $post['plugin'] : null;
                $this->_postFields['mobile'] = (isset($post['mobile'])) ? $post['mobile'] : null;
                $this->_postFields['file_id'] = $file->file_id;

            } else {
                foreach ($post as $key => $value) {
                    if (array_key_exists($key, $this->_postFields)) {
                        $this->_postFields[$key] = (isset($post[$key])) ? $post[$key] : null;
                    }
                }
                $this->_postFields['file_name'] = $fle_nme;
            }
        }

    }

}
