<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_Install
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_Install extends Moc10_Form
{

    /**
     * Form template
     * @var array
     */
    protected $_template = null;

    /**
     * $_POST fields
     * @var array
     */
    protected $_postFields = array('language' => null,
                                   'db_interface' => null,
                                   'db_name' => null,
                                   'db_username' => null,
                                   'db_password' => null,
                                   'db_host' => 'localhost',
                                   'db_prefix' => 'phire_',
                                   'base_path' => null,
                                   'sys_path' => '/phire',
                                   'content_path' => '/phire-content');

    /**
     * Initialization method for the install form.
     *
     * @param  array $post
     * @return void
     */
    public function init($post = null)
    {

        $this->_setFields($post);

        if (is_null($this->_postFields['base_path'])) {
            $bPath = substr($_SERVER['REQUEST_URI'], 0, strpos($_SERVER['REQUEST_URI'], '?'));
            $bPath = str_replace('/install.php', '', $bPath);
            $bPath = substr($bPath, 0, strrpos($bPath, '/'));
            $this->_postFields['base_path'] = $bPath;
        }

        $this->_setTemplates();

        $this->setAttributes('id', 'installForm');
        $lang = new Phire_Language();
        $langAry = $lang->getLanguages();
        ksort($langAry);

        // Create the default system language form element.
        $language = new Moc10_Form_Element_Select('language', $langAry, (isset($_GET['language']) ? $_GET['language'] : $this->_postFields['language']));
        $language->setLabel($lang->__('Select Language:'));
        $language->setAttributes('onchange', 'installFrm.installStep2(this.value);');

        $language->setRequired(true);

        $dbInterfaces = (function_exists('mysqli_connect')) ? array('MySQLi' => 'MySQLi', 'MySQL' => 'MySQL') : array('MySQL' => 'MySQL');

        // Create the db_interface form element.
        $db_interface = new Moc10_Form_Element_Select('db_interface', $dbInterfaces, (string)Moc10_String::setString($this->_postFields['db_interface'])->escape(true)->striptags());
        $db_interface->setLabel($lang->__('DB Interface:'));
        $db_interface->setRequired(true);

        // Create the db_name form element.
        $db_name = new Moc10_Form_Element('text', 'db_name', (string)Moc10_String::setString($this->_postFields['db_name'])->escape()->striptags());
        $db_name->setLabel($lang->__('DB Name:'));
        $db_name->setAttributes('size', '40');
        $db_name->setRequired(true);

        // Create the db_username form element.
        $db_username = new Moc10_Form_Element('text', 'db_username', (string)Moc10_String::setString($this->_postFields['db_username'])->escape()->striptags());
        $db_username->setLabel($lang->__('DB Username:'));
        $db_username->setAttributes('size', '40');
        $db_username->setRequired(true);

        // Create the db_password form element.
        $db_password = new Moc10_Form_Element('text', 'db_password', (string)Moc10_String::setString($this->_postFields['db_password'])->escape()->striptags());
        $db_password->setLabel($lang->__('DB Password:'));
        $db_password->setAttributes('size', '40');
        $db_password->setRequired(true);

        // Create the db_host form element.
        $db_host = new Moc10_Form_Element('text', 'db_host', (string)Moc10_String::setString($this->_postFields['db_host'])->escape()->striptags());
        $db_host->setLabel($lang->__('DB Host:'));
        $db_host->setAttributes('size', '40');
        $db_host->setRequired(true);

        // Test the DB connection.
        if (!is_null($this->_postFields['db_name']) && !is_null($this->_postFields['db_username']) && !is_null($this->_postFields['db_password']) && !is_null($this->_postFields['db_host'])) {
            define('DB_INTERFACE', (string)Moc10_String::setString($this->_postFields['db_interface'])->escape(true)->striptags());
            define('DB_NAME', (string)Moc10_String::setString($this->_postFields['db_name'])->escape()->striptags());
            define('DB_USER', (string)Moc10_String::setString($this->_postFields['db_username'])->escape()->striptags());
            define('DB_PASSWORD', (string)Moc10_String::setString($this->_postFields['db_password'])->escape()->striptags());
            define('DB_HOST', (string)Moc10_String::setString($this->_postFields['db_host'])->escape()->striptags());
            error_reporting(E_ALL ^ E_WARNING);
            try {
                $db = Moc10_Db::getInstance();
            } catch (Exception $e) {
                $db_host->addValidator('NotEqual', true, $this->_postFields['db_host'], $e->getMessage());
            }
        }

        // Create the db_prefix form element.
        $db_prefix = new Moc10_Form_Element('text', 'db_prefix', (string)Moc10_String::setString($this->_postFields['db_prefix'])->escape()->striptags());
        $db_prefix->setLabel($lang->__('DB Prefix:'));
        $db_prefix->setAttributes('size', '40');

        // Create the base_path form element.
        $base_path = new Moc10_Form_Element('text', 'base_path', (string)Moc10_String::setString($this->_postFields['base_path'])->escape()->striptags());
        $base_path->setLabel($lang->__('Base Path:'));
        $base_path->setAttributes('size', '57');
        $base_path->setAttributes('onkeyup', 'installFrm.changePaths(this.value);');

        if (!is_null($this->_postFields['base_path'])) {
            if (!is_dir($_SERVER['DOCUMENT_ROOT'] . $this->_postFields['base_path'])) {
                $base_path->addValidator('NotEqual', true, $this->_postFields['base_path'], $lang->__('The directory %1 does not exist.', $this->_postFields['base_path']));
            }
        }

        // Create the sys_path form element.
        $sys_path = new Moc10_Form_Element('text', 'sys_path', (string)Moc10_String::setString($this->_postFields['sys_path'])->escape()->striptags());
        $sys_path->setLabel($lang->__('System Path:'));
        $sys_path->setAttributes('size', '40');
        $sys_path->setRequired(true);

        if (!is_null($this->_postFields['sys_path'])) {
            if (!is_dir($_SERVER['DOCUMENT_ROOT'] . $this->_postFields['base_path'] . $this->_postFields['sys_path'])) {
                $sys_path->addValidator('NotEqual', true, $this->_postFields['sys_path'], $lang->__('The directory %1 does not exist.', $this->_postFields['base_path'] . $this->_postFields['sys_path']));
            }
        }

        // Create the content_path form element.
        $content_path = new Moc10_Form_Element('text', 'content_path', (string)Moc10_String::setString($this->_postFields['content_path'])->escape()->striptags());
        $content_path->setLabel($lang->__('Content Path:'));
        $content_path->setAttributes('size', '40');
        $content_path->setRequired(true);

        if (!is_null($this->_postFields['content_path'])) {
            if (!is_dir($_SERVER['DOCUMENT_ROOT'] . $this->_postFields['base_path'] . $this->_postFields['content_path'])) {
                $content_path->addValidator('NotEqual', true, $this->_postFields['content_path'], $lang->__('The directory %1 does not exist.', $this->_postFields['base_path'] . $this->_postFields['content_path']));
            }
        }

        // Create the 'writable' form element.
        $writable = new Moc10_Form_Element('hidden', 'writable', (!is_writable('config.php') ? 'false' : 'true'));
        $writable->addValidator('NotEqual', true, 'false', $lang->__('The \'config.php\' file is not writable. Please make it writable to continue.'));

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $lang->__('NEXT') . ' &gt;');
        $submit->setAttributes('class', 'submitBtn');

        // Set the form template and add the form element objects to the form.
        $this->setTemplate($this->_template);
        $this->addElements(array($language, $db_interface, $db_name, $db_username, $db_password, $db_host, $db_prefix, $base_path, $sys_path, $content_path, $writable, $submit));

    }

    /**
     * Method to process the form.
     *
     * @return void
     */
    public function process()
    {

        $prefix = ($this->_postFields['db_prefix'] == '') ? 'null' : "'" . $this->_postFields['db_prefix'] . "'";
        if (($this->_postFields['base_path'] == '') || ($this->_postFields['base_path'] == '/')) {
            $basePath = 'null';
            $realBasePath = null;
        } else {
            $basePath = (substr($this->_postFields['base_path'], -1) == '/') ? substr($this->_postFields['base_path'], 0, -1) : $this->_postFields['base_path'];
            $realBasePath = $basePath;
            $basePath = "'" . $basePath . "'";
        }
        $sysPath = (substr($this->_postFields['sys_path'], -1) == '/') ? substr($this->_postFields['sys_path'], 0, -1) : $this->_postFields['sys_path'];
        $contPath = (substr($this->_postFields['content_path'], -1) == '/') ? substr($this->_postFields['content_path'], 0, -1) : $this->_postFields['content_path'];


        $cfgOrgFile = new Moc10_File($_SERVER['DOCUMENT_ROOT'] . $realBasePath . $sysPath . '/config.orig.php');
        $cfgSettings = $cfgOrgFile->read();

        if (!file_exists($_SERVER['DOCUMENT_ROOT'] . $realBasePath . $sysPath . '/config.php')) {
            $cfgOrgFile->copy($_SERVER['DOCUMENT_ROOT'] . $realBasePath . $sysPath . '/config.php');
        }

        $cfgNewFile = new Moc10_File($_SERVER['DOCUMENT_ROOT'] . $realBasePath . $sysPath . '/config.php');

        $cfgSettings = str_replace("'DB_INTERFACE', ''", "'DB_INTERFACE', '" . $this->_postFields['db_interface'] . "'", $cfgSettings);
        $cfgSettings = str_replace("'DB_NAME', ''", "'DB_NAME', '" . $this->_postFields['db_name'] . "'", $cfgSettings);
        $cfgSettings = str_replace("'DB_USER', ''", "'DB_USER', '" . $this->_postFields['db_username'] . "'", $cfgSettings);
        $cfgSettings = str_replace("'DB_PASSWORD', ''", "'DB_PASSWORD', '" . $this->_postFields['db_password'] . "'", $cfgSettings);
        $cfgSettings = str_replace("'DB_HOST', ''", "'DB_HOST', '" . $this->_postFields['db_host'] . "'", $cfgSettings);
        $cfgSettings = str_replace("'DB_PREFIX', ''", "'DB_PREFIX', " . $prefix, $cfgSettings);
        $cfgSettings = str_replace("'BASE_PATH', '/phire-cms-1.1.2'", "'BASE_PATH', " . $basePath, $cfgSettings);
        $cfgSettings = str_replace("'SYS_PATH', '/phire'", "'SYS_PATH', '" . $sysPath . "'", $cfgSettings);
        $cfgSettings = str_replace("'CONTENT_PATH', '/phire-content'", "'CONTENT_PATH', '" . $contPath . "'", $cfgSettings);
        $cfgSettings = str_replace("'MOC10_LANG', 'en'", "'MOC10_LANG', '" . $_POST['language'] . "'", $cfgSettings);

        $cfgNewFile->write($cfgSettings);

    }

    /**
     * Method to set the post fields.
     *
     * @param  array $post
     * @return void
     */
    protected function _setFields($post = null)
    {

        if (!is_null($post)) {
            foreach ($post as $key => $value) {
                if (array_key_exists($key, $this->_postFields)) {
                    $this->_postFields[$key] = (isset($post[$key])) ? $post[$key] : null;
                }
            }
        }

    }

    /**
     * Method to set the form templates.
     *
     * @return void
     */
    protected function _setTemplates()
    {

        $lang = new Phire_Language();
        $blue = $lang->__('Blue fields are required.');
        $dbInfo = $lang->__('Database Information');
        $pathInfo = $lang->__('Path Information');
        $basePath = $lang->__('Leave the base path blank if you want the site and system to sit at the document root level.');
        $sysPath = $lang->__('Set the system path to the folder that you would like to access the system under the base path.');
        $contPath = $lang->__('Set the content path to the folder that you would like to save your content to under the base path (such as files and images.)');

        // Define the main form template.
        $this->_template = <<<FORMTEMP
            <table id="installTable" cellpadding="0" cellspacing="0">
                <tr>
                    <td>
                        &nbsp;
                    </td>
                    <td>
                        [{writable}]
                    </td>
                </tr>
                <tr>
                    <td>
                        &nbsp;
                    </td>
                    <td>
                        <em style="color: #008aff;">{$blue}</em>
                    </td>
                </tr>
                <tr>
                    <td class="textRight">
                        [{language_label}]
                    </td>
                    <td>
                        [{language}]
                    </td>
                </tr>
                <tr>
                    <td colspan="2">
                        &nbsp;
                    </td>
                </tr>

FORMTEMP;

        if (isset($_GET['language'])) {

            $domain = '<strong style="color: #bbb;">http://' . $_SERVER['HTTP_HOST'] . '</strong>';
            $this->setAttributes('onsubmit', "return installFrm.validate();");
            $this->_template .= <<<FORMTEMP
                <tr>
                    <td>
                        &nbsp;
                    </td>
                    <td>
                        <h4>{$dbInfo}</h4>
                    </td>
                </tr>
                <tr>
                    <td class="textRight">
                        [{db_interface_label}]
                    </td>
                    <td>
                        [{db_interface}]
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        [{db_name_label}]
                    </td>
                    <td>
                        [{db_name}]
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        [{db_username_label}]
                    </td>
                    <td>
                        [{db_username}]
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        [{db_password_label}]
                    </td>
                    <td>
                        [{db_password}]
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        [{db_host_label}]
                    </td>
                    <td>
                        [{db_host}]
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        [{db_prefix_label}]
                    </td>
                    <td>
                        [{db_prefix}]
                    </td>
                </tr>
                <tr>
                    <td colspan="2">
                        &nbsp;
                    </td>
                </tr>
                <tr>
                    <td>
                        &nbsp;
                    </td>
                    <td>
                        <h4>{$pathInfo}</h4>
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight" style="padding-top: 8px;">
                        [{base_path_label}]
                    </td>
                    <td>
                        {$domain} [{base_path}]<br />
                        <span style="font-size: 0.825em;">{$basePath}</span>
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight" class="textTopRight" style="padding-top: 8px;">
                        [{sys_path_label}]
                    </td>
                    <td>
                        {$domain}<strong style="color: #bbb;" id="basePath1">{$this->_postFields['base_path']} </strong>[{sys_path}]<br />
                        <span style="font-size: 0.825em;">{$sysPath}</span>
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight" class="textTopRight" style="padding-top: 8px;">
                        [{content_path_label}]
                    </td>
                    <td>
                        {$domain}<strong style="color: #bbb;" id="basePath2">{$this->_postFields['base_path']} </strong>[{content_path}]<br />
                        <span style="font-size: 0.825em;">{$contPath}</span>
                    </td>
                </tr>
                <tr>
                    <td colspan="2">
                        &nbsp;
                    </td>
                </tr>
                <tr>
                    <td class="textRight">
                        &nbsp;
                    </td>
                    <td>
                        [{submit}]
                    </td>
                </tr>

FORMTEMP;
        }

        $step = (isset($_GET['language'])) ? 2 : 1;

        $this->_template .= <<<FORMTEMP
            </table>
            <script type="text/javascript">
                installFormInit({$step});
            </script>
FORMTEMP;

    }

}
