<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_Page
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_Page extends Moc10_Form
{

    /**
     * Page object
     * @var Phire_Table_Pages
     */
    public $page = null;

    /**
     * Form templates
     * @var array
     */
    protected $_templates = array('main' => null, 'mobile' => null, 'tags' => null, 'mobile_tags' => null);

    /**
     * $_POST fields
     * @var array
     */
    protected $_postFields = array('plugin' => null,
                                   'page_user_id' => 0,
                                   'site_id' => 0,
                                   'section_id' => 0,
                                   'template_id' => -1,
                                   'page_url' => null,
                                   'page_charset' => null,
                                   'page_title' => null,
                                   'page_author' => null,
                                   'page_keywords' => null,
                                   'page_desc' => null,
                                   'page_robots' => null,
                                   'page_content' => null,
                                   'page_filter' => null,
                                   'auto_links' => null,
                                   'page_form_tags' => null,
                                   'page_access' => null,
                                   'comments_allowed' => 'No',
                                   'ssl_connection' => 'No',
                                   'published' => 'No',
                                   'feed' => 'No',
                                   'flush_stats' => 'No',
                                   'cur_page_url' => null,
                                   'cont_edit' => null,
                                   'pub_month' => null,
                                   'pub_day' => null,
                                   'pub_year' => null,
                                   'pub_hour' => null,
                                   'pub_min' => null,
                                   'exp_month' => null,
                                   'exp_day' => null,
                                   'exp_year' => null,
                                   'exp_hour' => null,
                                   'exp_min' => null,
                                   'mobile' => null,
                                   'page_id' => 0);

    /**
     * Language object
     * @var Phire_Language
     */
    protected $_lang = null;

    /**
     * Initialization method for the page form.
     *
     * @param  array $post
     * @return void
     */
    public function init($post = null)
    {

        $this->_lang = new Phire_Language();

        $this->_setFields($post);
        $this->_setTemplates();

        $this->setAttributes('id', 'addPageForm');

        $sess = Moc10_Session::getInstance();
        $sitesAry = Phire_Sites::getAllowedSites(true);

        // Get templates.
        $tmpls = new Phire_Table_Templates();
        if ($this->_postFields['site_id'] == 0) {
            $tmpls->findAll('template_id ASC', 'site_id', $sitesAry['first_site_id']);
        } else {
            $tmpls->findAll('template_id ASC', 'site_id', $this->_postFields['site_id']);
        }
        $tmplAry = array('-1' => '(' . $this->_lang->__('None') . ')', '0' => '(' . $this->_lang->__('Site Default') . ')');
        foreach ($tmpls->rows as $tmpl) {
            if (in_array($tmpl->site_id, $sess->sites)) {
                $tmplAry[$tmpl->template_id] = $tmpl->template_name;
            }
        }

        // Create the 'template_id' form element.
        $template_id = new Moc10_Form_Element_Select('template_id', $tmplAry, $this->_postFields['template_id']);
        $template_id->setLabel($this->_lang->__('Template:'));
        $template_id->setAttributes('style', 'float: left;');

        // Get sections.
        $sects = new Phire_Table_Sections();
        if ($this->_postFields['site_id'] == 0) {
            $sects->findAll('section_id ASC', 'site_id', $sitesAry['first_site_id']);
        } else {
            $sects->findAll('section_id ASC', 'site_id', $this->_postFields['site_id']);
        }
        $sectAry = array('0' => '(' . $this->_lang->__('None') . ')');
        if (isset($sects->rows[0])) {
            foreach ($sects->rows as $sect) {
                $sectAry[$sect->section_id] = $sect->section_title;
            }
        }

        // Create the 'section_id' form element.
        $section_id = new Moc10_Form_Element_Select('section_id', $sectAry, $this->_postFields['section_id']);
        $section_id->setLabel($this->_lang->__('Section:'));
        $section_id->setAttributes('style', 'float: left;');

        // Get character sets.
        $chrs = new Phire_Table_Charsets();
        $chrs->findAll('charset_id ASC');
        $chrsAry = array();
        foreach ($chrs->rows as $chr) {
            $chrsAry[$chr->charset_id] = $chr->charset;
        }

        // Create the 'page_charset' form element.
        $page_charset = new Moc10_Form_Element_Select('page_charset', $chrsAry, $this->_postFields['page_charset']);
        $page_charset->setLabel(((!is_null($this->_postFields['mobile'])) ? $this->_lang->__('Charset:') : $this->_lang->__('Character Set:')));

        // Get robots.
        $robs = new Phire_Table_Robots();
        $robs->findAll('robot_id ASC');
        $robsAry = array();
        foreach ($robs->rows as $rob) {
            $robsAry[$rob->robot_id] = $rob->robots;
        }

        // Create the 'page_robots' form element.
        $page_robots = new Moc10_Form_Element_Select('page_robots', $robsAry, $this->_postFields['page_robots']);
        $page_robots->setLabel($this->_lang->__('Robots:'));

        // Create the 'page_title' form element.
        $page_title = new Moc10_Form_Element('text', 'page_title', $this->_postFields['page_title']);
        $page_title->setLabel($this->_lang->__('Title:'));
        $page_title->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '25' : '150'));
        $page_title->setRequired(true);

        // Create the 'page_url' form element.
        $page_url = new Moc10_Form_Element('text', 'page_url', $this->_postFields['page_url']);
        $page_url->setLabel($this->_lang->__('URL:'));
        $page_url->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '25' : '150'));
        $page_url->setRequired(true);

        // Add additional attributes for the page title and page URL.
        if ($this->_postFields['page_id'] == 0) {
            $page_title->setAttributes('onkeyup', "addPageFrm.convertPageURL('page_title', 'page_url', '" . $sitesAry['title_sep'] . "'); xmlhttp.getRequest('../core/process/check.page.url.php?current=" . $this->_postFields['cur_page_url'] . "&url=' + addPageFrm.fo.page_url.value + '&site_id=' + addPageFrm.fo.site_id.value + '&section_id=' + addPageFrm.fo.section_id.value, addPageFrm.checkURL); return false;");
        } else {
            $page_url->setAttributes('onkeyup', "xmlhttp.getRequest('../core/process/check.page.url.php?current=" . $this->_postFields['cur_page_url'] . "&url=' + addPageFrm.fo.page_url.value + '&site_id=' + addPageFrm.fo.site_id.value + '&section_id=' + addPageFrm.fo.section_id.value, addPageFrm.checkURL); return false;");
        }

        if (!is_null($this->_postFields['page_url'])) {
            if ((substr($this->_postFields['page_url'], 0, 1) != '/') && (substr($this->_postFields['page_url'], 0, 7) != 'http://')) {
                $page_url->addValidator('NotEqual', true, $this->_postFields['page_url'], $this->_lang->__("The page URL must begin with either a '/' (forward slash), or an 'http://'."));
            }
        }

        // If the form has been submitted, validate the page URL.
        if (($this->_postFields['site_id'] != 0) && (!is_null($this->_postFields['page_url'])) && ($this->_postFields['page_url'] != $this->_postFields['cur_page_url'])) {
            $dupe_url = new Phire_Table_Pages();
            $dupe_url->execute("SELECT * FROM " . DB_PREFIX . "pages WHERE page_url = '" . (string)Moc10_String::setString($this->_postFields['page_url'])->escape()->striptags() . "' AND site_id = '" . (string)Moc10_String::setString($this->_postFields['site_id'])->escape(true)->striptags() . "' LIMIT 1");
            $dupe_sect_url = new Phire_Table_Sections();
            $dupe_sect_url->execute("SELECT * FROM " . DB_PREFIX . "sections WHERE section_url = '" . (string)Moc10_String::setString($this->_postFields['page_url'])->escape()->striptags() . "' AND site_id = '" . (string)Moc10_String::setString($this->_postFields['site_id'])->escape(true)->striptags() . "' LIMIT 1");
            if ((isset($dupe_url->rows[0])) || (isset($dupe_sect_url->rows[0]))) {
                $page_url->addValidator('NotEqual', true, $this->_postFields['page_url'], $this->_lang->__('That URL already exists in the system for that site. Please choose another URL.'));
            } else if ((substr($this->_postFields['page_url'], 0, strlen(BASE_PATH . SYS_PATH)) == BASE_PATH . SYS_PATH) || (substr($this->_postFields['page_url'], 0, 7) == '/search') || (substr($this->_postFields['page_url'], 0, 4) == '/feed') || (substr($this->_postFields['page_url'], 0, 5) == '/user') || (substr($this->_postFields['page_url'], 0, 7) == '/member') || (substr($this->_postFields['page_url'], 0, 4) == '/tag') || (substr($this->_postFields['page_url'], 0, 8) == '/captcha')) {
                $page_url->addValidator('NotEqual', true, $this->_postFields['page_url'], $this->_lang->__('That URL is a reserved system URL. Please choose another URL.'));
            }
        }

        // Create the 'page_author' form element.
        $page_author = new Moc10_Form_Element('text', 'page_author', $this->_postFields['page_author']);
        $page_author->setLabel($this->_lang->__('Author:'));
        $page_author->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '25' : '150'));

        // Create the 'page_keywords' form element.
        $page_keywords = new Moc10_Form_Element('text', 'page_keywords', $this->_postFields['page_keywords']);
        $page_keywords->setLabel($this->_lang->__('Keywords:'));
        $page_keywords->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '25' : '150'));

        // Create the 'page_desc' form element.
        $page_desc = new Moc10_Form_Element('text', 'page_desc', $this->_postFields['page_desc']);
        $page_desc->setLabel($this->_lang->__('Description:'));
        $page_desc->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '25' : '150'));

        if ((!is_null($this->page)) && ($this->page->created != '0000-00-00 00:00:00')) {
            $pubAry = explode(' ', $this->page->created);
            $dtAry = explode('-', $pubAry[0]);
            $tmAry = explode(':', $pubAry[1]);
        } else {
            $dtAry = explode('-', date('Y-m-d'));
            $tmAry = explode(':', date('H:i:s'));
        }

        // Create the 'pub_month' form element.
        $pub_month = new Moc10_Form_Element_Select('pub_month', 'MONTHS_SHORT', $dtAry[1]);
        $pub_month->setLabel($this->_lang->__('Publish Date:'));

        // Create the 'pub_day' form element.
        $pub_day = new Moc10_Form_Element_Select('pub_day', 'DAYS_OF_MONTH', $dtAry[2]);

        // Create the 'pub_year' form element.
        $pub_year = new Moc10_Form_Element_Select('pub_year', 'YEAR_' . (date('Y') + 10) . '_' . (date('Y') - 20), $dtAry[0]);

        // Create the 'pub_hour' form element.
        $pub_hour = new Moc10_Form_Element_Select('pub_hour', 'MILITARY_HOURS', $tmAry[0]);

        // Create the 'pub_min' form element.
        $pub_min = new Moc10_Form_Element_Select('pub_min', 'MINUTES', $tmAry[1]);

        if ((!is_null($this->page)) && ($this->page->expire != '0000-00-00 00:00:00')) {
            $expAry = explode(' ', $this->page->expire);
            $dtAry = explode('-', $expAry[0]);
            $tmAry = explode(':', $expAry[1]);
        } else {
            $dtAry = array('----', '--', '--');
            $tmAry = array('--', '--', '--');
        }

        // Create the 'exp_month' form element.
        $exp_month = new Moc10_Form_Element_Select('exp_month', 'MONTHS_SHORT', $dtAry[1]);

        // Create the 'exp_day' form element.
        $exp_day = new Moc10_Form_Element_Select('exp_day', 'DAYS_OF_MONTH', $dtAry[2]);

        // Create the 'exp_year' form element.
        $exp_year = new Moc10_Form_Element_Select('exp_year', 'YEAR_' . (date('Y') + 10) . '_' . (date('Y') - 20), $dtAry[0]);

        // Create the 'exp_hour' form element.
        $exp_hour = new Moc10_Form_Element_Select('exp_hour', 'MILITARY_HOURS', $tmAry[0]);

        // Create the 'exp_min' form element.
        $exp_min = new Moc10_Form_Element_Select('exp_min', 'MINUTES', $tmAry[1]);

        // Get the WYSIWYG editors.
        $editors = array('Native' => $this->_lang->__('Native'));
        if (file_exists('../core/scripts/ckeditor')) {
            $editors['CKEditor'] = 'CKEditor';
        }
        if (file_exists('../core/scripts/tinymce')) {
            $editors['TinyMCE'] = 'TinyMCE';
        }

        $cfg = new Phire_Table_Config();

        // Create the 'editor' form element.
        $editor = new Moc10_Form_Element_Select('editor', $editors, $cfg->settings['default_editor']);
        $editor->setAttributes('onchange', 'addPageFrm.changeEditor(this.value);');
        $editor->setLabel($this->_lang->__('Editor:'));

        // Create the 'page_content' form element.
        $page_content = new Moc10_Form_Element_Textarea('page_content', $this->_postFields['page_content']);
        $page_content->setLabel($this->_lang->__('Content:'));
        $page_content->setAttributes('cols', ((!is_null($this->_postFields['mobile'])) ? '30' : '150'));
        $page_content->setAttributes('rows', ((!is_null($this->_postFields['mobile'])) ? '8' : '20'));
        $page_content->setAttributes('spellcheck', 'false');
        $page_content->setAttributes('wrap', 'soft');

        // Create the 'page_filter' form element.
        $page_filter = new Moc10_Form_Element_Select('page_filter', array('None' => $this->_lang->__('None'), '<br />' => '&lt;br /&gt;', '<p>' => '&lt;p&gt;'), $this->_postFields['page_filter']);
        $page_filter->setLabel($this->_lang->__('Page Filter:'));

        // Create the 'auto_links' form element.
        $auto_links = new Moc10_Form_Element_Checkbox('auto_links', array('Links' => $this->_lang->__('Auto-Links?'), 'New' => $this->_lang->__('New Window?')), $this->_postFields['auto_links']);

        // Create the 'page_access' form element.
        $page_access = new Moc10_Form_Element_Select('page_access', array('Public' => $this->_lang->__('Public'), 'Private' => $this->_lang->__('Private')), $this->_postFields['page_access']);
        $page_access->setLabel($this->_lang->__('Page Access:'));

        // Create the 'comment_allowed' form element.
        $comments_allowed = new Moc10_Form_Element_Radio('comments_allowed', array('Yes' => $this->_lang->__('Yes'), 'No' => $this->_lang->__('No')), $this->_postFields['comments_allowed']);
        $comments_allowed->setLabel(((!is_null($this->_postFields['mobile'])) ? $this->_lang->__('Comments?') : $this->_lang->__('Comments Allowed?')));

        // Create the 'feed' form element.
        $feed = new Moc10_Form_Element_Radio('feed', array('Yes' => $this->_lang->__('Yes'), 'No' => $this->_lang->__('No')), $this->_postFields['feed']);
        $feed->setLabel(((!is_null($this->_postFields['mobile'])) ? $this->_lang->__('Feed?') : $this->_lang->__('Include in the Feed?')));

        // Create the 'ssl_connection' form element.
        $ssl_connection = new Moc10_Form_Element_Radio('ssl_connection', array('Yes' => $this->_lang->__('Yes'), 'No' => $this->_lang->__('No')), $this->_postFields['ssl_connection']);
        $ssl_connection->setLabel(((!is_null($this->_postFields['mobile'])) ? $this->_lang->__('SSL?') : $this->_lang->__('SSL Connection:')));

        // Create the 'flush_stats' form element.
        $flush_stats = new Moc10_Form_Element_Radio('flush_stats', array('Yes' => $this->_lang->__('Yes'), 'No' => $this->_lang->__('No')), $this->_postFields['flush_stats']);
        $flush_stats->setLabel(((!is_null($this->_postFields['mobile'])) ? $this->_lang->__('Flush Stats?') : $this->_lang->__('Flush Page Stats?')));

        // Create the 'published' form element.
        $published = new Moc10_Form_Element_Select('published', array('No' => $this->_lang->__('No'), 'Yes' => $this->_lang->__('Yes'), 'Draft' => $this->_lang->__('Draft')), $this->_postFields['published']);
        $published->setLabel($this->_lang->__('Publish?'));
        $published->setRequired(true);

        // Create the 'cur_page_url' form element.
        $cur_page_url = new Moc10_Form_Element('hidden', 'cur_page_url', $this->_postFields['cur_page_url']);

        // Create the 'page_user_id' form element.
        $page_user_id = new Moc10_Form_Element('hidden', 'page_user_id', $this->_postFields['page_user_id']);

        // Create the 'page_id' form element.
        $page_id = new Moc10_Form_Element('hidden', 'page_id', $this->_postFields['page_id']);

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $this->_lang->__('SAVE'));
        $submit->setAttributes('style', 'float: right;');

        // Get tags.
        $tags = new Phire_Table_Tags();
        if ($this->_postFields['site_id'] == 0) {
            $tags->findAll('tag_id ASC', 'site_id', $sitesAry['first_site_id']);
        } else {
            $tags->findAll('tag_id ASC', 'site_id', $this->_postFields['site_id']);
        }

        $tagsAry = array();
        foreach ($tags->rows as $tag) {
            $tagsAry[$tag->tag_id] = $tag->tag;
        }

        // Create the 'page_form_tags' form element.
        $page_form_tags = new Moc10_Form_Element_Checkbox('page_form_tags', $tagsAry, $this->_postFields['page_form_tags']);
        $page_form_tags->setLabel($this->_lang->__('Page Tags:'));

        $tmpl = '';

        // Set form templates based on if there are any available tags.
        if (count($tagsAry) != 0) {
            if (!is_null($this->_postFields['mobile'])) {
                $tmpl = str_replace('[{page_tags_tmpl}]', $this->_templates['mobile_tags'], $this->_templates['mobile']);
            } else {
                $tmpl = str_replace('[{page_tags_tmpl}]', $this->_templates['tags'], $this->_templates['main']);
            }
        } else {
            if (!is_null($this->_postFields['mobile'])) {
                $tmpl = str_replace('[{page_tags_tmpl}]', '', $this->_templates['mobile']);
            } else {
                $tmpl = str_replace('[{page_tags_tmpl}]', '', $this->_templates['main']);
            }
        }

        // Set whether it's a mobile form template or not.
        if (!is_null($this->_postFields['mobile'])) {
            $sess = Moc10_Session::getInstance();
            $exp_month->setLabel($this->_lang->__('Exp Date:'));
            $submit->setAttributes('class', 'submitBtn');
            $site_id = new Moc10_Form_Element('hidden', 'site_id', $sess->cur_site_id);
        } else {
            $this->setAttributes('onsubmit', "return addPageFrm.validatePageFrm();");
            $exp_month->setLabel($this->_lang->__('Expiration Date:'));
            $site_id = new Moc10_Form_Element_Select('site_id', $sitesAry['sites'], $this->_postFields['site_id']);
            $submit->setAttributes('class', 'submitBtn');
            $site_id->setLabel($this->_lang->__('Add to Site:'));
            $site_id->setAttributes('onchange', "xmlhttp.getRequest('../core/process/check.page.site.php?site_id=' + this.value, addPageFrm.changeSiteId); return false;");
            $page_content->setAttributes('style', 'width: 800px;');
            $page_title->setAttributes('style', 'width: 800px;');
            $page_url->setAttributes('style', 'width: 800px;');
            $page_author->setAttributes('style', 'width: 800px;');
            $page_keywords->setAttributes('style', 'width: 800px;');
            $page_desc->setAttributes('style', 'width: 800px;');
            $page_filter->setAttributes('style', 'float: left; margin: 0 30px 0 0;');
        }

        $elems = array($site_id, $template_id, $section_id, $page_charset, $page_robots, $page_title, $page_url, $page_author, $page_keywords, $page_desc, $editor, $page_content, $page_filter, $auto_links, $page_access, $comments_allowed, $feed, $flush_stats, $ssl_connection, $published, $submit, $cur_page_url, $page_user_id, $pub_month, $pub_day, $pub_year, $pub_hour, $pub_min, $exp_month, $exp_day, $exp_year, $exp_hour, $exp_min, $page_id);

        if (count($tagsAry) != 0) {
            $elems[] = $page_form_tags;
        }

        // Add the form element objects to the form.
        $this->setTemplate($tmpl);
        $this->addElements($elems);

    }

    /**
     * Method to save the page data.
     *
     * @return void
     */
    public function saveData()
    {

        $page_filter = '';
        if (isset($this->_postFields['auto_links'][0])) {
            if ((in_array('Links', $this->_postFields['auto_links'])) && (in_array('New', $this->_postFields['auto_links']))) {
                $page_filter = $this->_postFields['page_filter'] . '+Links+New';
            } else if (in_array('Links', $this->_postFields['auto_links'])) {
                $page_filter = $this->_postFields['page_filter'] . '+Links';
            }
        } else {
            $page_filter = $this->_postFields['page_filter'];
        }

        // Edit existing page.
        if ($this->_postFields['page_id'] != 0) {

            $this->page = new Phire_Table_Pages();
            $this->page->findById($this->_postFields['page_id']);

            if (($this->_postFields['pub_month'] != '--') && ($this->_postFields['pub_day'] != '--') && ($this->_postFields['pub_year'] != '----')) {
                $pub_date = $this->_postFields['pub_year'] . '-' . $this->_postFields['pub_month'] . '-' . $this->_postFields['pub_day'];
                if (($this->_postFields['pub_hour'] != '--') && ($this->_postFields['pub_min'] != '--')) {
                    $pub_date .= ' ' . $this->_postFields['pub_hour'] . ':' . $this->_postFields['pub_min'] . ':00';
                } else {
                    $pub_date .= ' 00:00:00';
                }
            } else {
                $pub_date = $this->page->created;
            }

            if (($this->_postFields['exp_month'] != '--') && ($this->_postFields['exp_day'] != '--') && ($this->_postFields['exp_year'] != '----')) {
                $exp_date = $this->_postFields['exp_year'] . '-' . $this->_postFields['exp_month'] . '-' . $this->_postFields['exp_day'];
                if (($this->_postFields['exp_hour'] != '--') && ($this->_postFields['exp_min'] != '--')) {
                    $exp_date .= ' ' . $this->_postFields['exp_hour'] . ':' . $this->_postFields['exp_min'] . ':00';
                } else {
                    $exp_date .= ' 00:00:00';
                }
            } else {
                $exp_date = '0000-00-00 00:00:00';
            }

            $this->page->site_id = $this->_postFields['site_id'];
            $this->page->user_id = ($this->_postFields['page_user_id'] == 0) ? $sess->user_id : $this->_postFields['page_user_id'];
            $this->page->section_id = $this->_postFields['section_id'];
            $this->page->template_id = $this->_postFields['template_id'];
            $this->page->page_url = $this->_postFields['page_url'];
            $this->page->page_charset = $this->_postFields['page_charset'];
            $this->page->page_title = $this->_postFields['page_title'];
            $this->page->page_author = $this->_postFields['page_author'];
            $this->page->page_keywords = $this->_postFields['page_keywords'];
            $this->page->page_desc = $this->_postFields['page_desc'];
            $this->page->page_robots = $this->_postFields['page_robots'];
            $this->page->page_content = $this->_postFields['page_content'];
            $this->page->page_filter = $page_filter;
            $this->page->page_tags = ((!is_null($this->_postFields['page_form_tags'])) ? implode('|', $this->_postFields['page_form_tags']) : '');
            $this->page->page_access = $this->_postFields['page_access'];
            $this->page->page_requests = ($this->_postFields['flush_stats'] == 'Yes') ? 0 : $this->page->page_requests;
            $this->page->comments_allowed = $this->_postFields['comments_allowed'];
            $this->page->feed = $this->_postFields['feed'];
            $this->page->force_ssl_connection = $this->_postFields['ssl_connection'];
            $this->page->published = $this->_postFields['published'];
            $this->page->created = $pub_date;
            $this->page->updated = date('Y-m-d H:i:s');
            $this->page->expire = $exp_date;

        // Else, save new page.
        } else {

            if (($this->_postFields['pub_month'] != '--') && ($this->_postFields['pub_day'] != '--') && ($this->_postFields['pub_year'] != '----')) {
                $pub_date = $this->_postFields['pub_year'] . '-' . $this->_postFields['pub_month'] . '-' . $this->_postFields['pub_day'];
                if (($this->_postFields['pub_hour'] != '--') && ($this->_postFields['pub_min'] != '--')) {
                    $pub_date .= ' ' . $this->_postFields['pub_hour'] . ':' . $this->_postFields['pub_min'] . ':00';
                } else {
                    $pub_date .= ' 00:00:00';
                }
            } else {
                $pub_date = date('Y-m-d H:i:s');
            }

            if (($this->_postFields['exp_month'] != '--') && ($this->_postFields['exp_day'] != '--') && ($this->_postFields['exp_year'] != '----')) {
                $exp_date = $this->_postFields['exp_year'] . '-' . $this->_postFields['exp_month'] . '-' . $this->_postFields['exp_day'];
                if (($this->_postFields['exp_hour'] != '--') && ($this->_postFields['exp_min'] != '--')) {
                    $exp_date .= ' ' . $this->_postFields['exp_hour'] . ':' . $this->_postFields['exp_min'] . ':00';
                } else {
                    $exp_date .= ' 00:00:00';
                }
            } else {
                $exp_date = '0000-00-00 00:00:00';
            }

            // Add the new page in the system.
            $fields = array('site_id' => $this->_postFields['site_id'],
                            'user_id' => $this->_postFields['page_user_id'],
                            'section_id' => $this->_postFields['section_id'],
                            'template_id' => $this->_postFields['template_id'],
                            'page_url' => $this->_postFields['page_url'],
                            'page_charset' => $this->_postFields['page_charset'],
                            'page_title' => $this->_postFields['page_title'],
                            'page_author' => $this->_postFields['page_author'],
                            'page_keywords' => $this->_postFields['page_keywords'],
                            'page_desc' => $this->_postFields['page_desc'],
                            'page_robots' => $this->_postFields['page_robots'],
                            'page_content' => $this->_postFields['page_content'],
                            'page_filter' => $page_filter,
                            'page_tags' => ((!is_null($this->_postFields['page_form_tags'])) ? implode('|', $this->_postFields['page_form_tags']) : ''),
                            'page_access' => $this->_postFields['page_access'],
                            'page_requests' => 0,
                            'comments_allowed' => $this->_postFields['comments_allowed'],
                            'feed' => $this->_postFields['feed'],
                            'force_ssl_connection' => $this->_postFields['ssl_connection'],
                            'published' => $this->_postFields['published'],
                            'created' =>  $pub_date,
                            'updated' => '0000-00-00 00:00:00',
                            'expire' => $exp_date);

            $this->page = new Phire_Table_Pages($fields);

        }

        $this->page->save();

        $site = new Phire_Table_Sites();
        $site->findById($this->_postFields['site_id']);

        // Create the cache file, if applicable.
        if ($site->page_caching == 'On') {
            // Get Page.
            $pg = new Phire_Page($this->page->page_id, $site->site_id, true);
            $pg->init();

            // Get page content type from template.
            $tmpl = new Phire_Table_Templates();
            $tmpl->join(DB_PREFIX . 'content_types', 'type_id', null, 'template_id', $this->page->template_id, 1);

            // Get section access, if applicable.
            if ($this->page->section_id != 0) {
                $sect = new Phire_Table_Sections();
                $sect->findById($this->page->section_id);
                $section_access = $sect->section_access;
            } else {
                $section_access = 'Public';
            }

            // Get SSL settings for page and site.
            $page_ssl = ($this->page->force_ssl_connection == 'Yes') ? 443 : 80;
            $site_ssl = ($site->use_ssl_connection == 'Yes') ? 443 : 80;

            $cache_file_headers = $tmpl->rows[0]['type'] . "|" . $this->page->page_access . '_' . $section_access . "|" . $page_ssl . '_' . $site_ssl . '|' . $this->page->published . '_' . $site->site_live . '|' . $site->site_id . "\n";

            $filename = $site->site_docroot . BASE_PATH . CONTENT_PATH . '/cache/' . sha1($this->page->page_url) . '.txt';
            $cache_file = new Moc10_File($filename);
            $cache_file->write($cache_file_headers . $pg->getPage());

            if ($tmpl->mobile_template != '') {
                $mob_filename = $site->site_docroot . BASE_PATH . CONTENT_PATH . '/cache/mobile/' . sha1($this->page->page_url) . '.txt';
                $mob_cache_file = new Moc10_File($mob_filename);
                $mob_cache_file->write($cache_file_headers . $pg->getMobilePage());
            }

        }

    }

    /**
     * Method to set the post fields.
     *
     * @param  array $post
     * @return void
     */
    protected function _setFields($post = null)
    {

        if (!is_null($post)) {
            if ((!$_POST) && isset($post['page_id']) && ($post['page_id'] != 0)) {

                $this->page = new Phire_Table_Pages();
                $this->page->findById($post['page_id']);

                $pg_filt = Moc10_String::setString($this->page->page_filter)->split('+');
                $lnks = array();
                if (isset($pg_filt[2])) {
                    $lnks = array('Links', 'New');
                } else if (isset($pg_filt[1])) {
                    $lnks = array('Links');
                }

                $this->_postFields['site_id'] = $this->page->site_id;
                $this->_postFields['page_user_id'] = $this->page->user_id;
                $this->_postFields['site_id'] = $this->page->site_id;
                $this->_postFields['section_id'] = $this->page->section_id;
                $this->_postFields['template_id'] = $this->page->template_id;
                $this->_postFields['page_url'] = (string)Moc10_String::setString($this->page->page_url)->strip()->html();
                $this->_postFields['page_charset'] = $this->page->page_charset;
                $this->_postFields['page_title'] = (string)Moc10_String::setString($this->page->page_title)->strip()->html();
                $this->_postFields['page_author'] = (string)Moc10_String::setString($this->page->page_author)->strip()->html();
                $this->_postFields['page_keywords'] = (string)Moc10_String::setString($this->page->page_keywords)->strip()->html();
                $this->_postFields['page_desc'] = (string)Moc10_String::setString($this->page->page_desc)->strip()->html();
                $this->_postFields['page_robots'] = $this->page->page_robots;
                $this->_postFields['page_content'] = (string)Moc10_String::setString($this->page->page_content)->strip()->html();
                $this->_postFields['page_filter'] = $pg_filt[0];
                $this->_postFields['auto_links'] = $lnks;
                $this->_postFields['page_form_tags'] = explode('|', $this->page->page_tags);
                $this->_postFields['page_access'] = $this->page->page_access;
                $this->_postFields['comments_allowed'] = $this->page->comments_allowed;
                $this->_postFields['ssl_connection'] = $this->page->force_ssl_connection;
                $this->_postFields['published'] = $this->page->published;
                $this->_postFields['feed'] = $this->page->feed;
                $this->_postFields['flush_stats'] = (isset($post['flush_stats'])) ? $post['flush_stats'] : 'No';
                $this->_postFields['pub_month'] = (isset($post['pub_month'])) ? $post['pub_month'] : null;
                $this->_postFields['pub_day'] = (isset($post['pub_day'])) ? $post['pub_day'] : null;
                $this->_postFields['pub_year'] = (isset($post['pub_year'])) ? $post['pub_year'] : null;
                $this->_postFields['pub_hour'] = (isset($post['pub_hour'])) ? $post['pub_hour'] : null;
                $this->_postFields['pub_min'] = (isset($post['pub_min'])) ? $post['pub_min'] : null;
                $this->_postFields['exp_month'] = (isset($post['exp_month'])) ? $post['exp_month'] : null;
                $this->_postFields['exp_day'] = (isset($post['exp_day'])) ? $post['exp_day'] : null;
                $this->_postFields['exp_year'] = (isset($post['exp_year'])) ? $post['exp_year'] : null;
                $this->_postFields['exp_hour'] = (isset($post['exp_hour'])) ? $post['exp_hour'] : null;
                $this->_postFields['exp_min'] = (isset($post['exp_min'])) ? $post['exp_min'] : null;
                $this->_postFields['cont_edit'] = (isset($post['cont_edit'])) ? $post['cont_edit'] : null;
                $this->_postFields['cur_page_url'] = $this->_postFields['page_url'];
                $this->_postFields['plugin'] = (isset($post['plugin'])) ? $post['plugin'] : null;
                $this->_postFields['mobile'] = (isset($post['mobile'])) ? $post['mobile'] : null;
                $this->_postFields['page_id'] = $this->page->page_id;

            } else {
                foreach ($post as $key => $value) {
                    if (array_key_exists($key, $this->_postFields)) {
                        $this->_postFields[$key] = (isset($post[$key])) ? $post[$key] : null;
                    }
                }
            }
        }

    }

    /**
     * Method to set the form templates.
     *
     * @return void
     */
    protected function _setTemplates()
    {

        if (!is_null($this->_postFields['mobile'])) {

            if (!is_null($this->page)) {
                $dateStamp = "<span style=\"padding: 0 5px 0 5px;\"><strong>Reqs:</strong> " . $this->page->page_requests;
                $created = ($this->page->created != '0000-00-00 00:00:00') ? '<strong>Crtd:</strong> ' . date('m/d/y H:i', strtotime($this->page->created)) : '<strong>Crtd:</strong> Never';
                $last_update = ($this->page->updated != '0000-00-00 00:00:00') ? '<strong>Uptd:</strong> ' . date('m/d/y H:i', strtotime($this->page->updated)) : '<strong>Uptd:</strong> Never';
                $dateStamp = "<span style=\"padding: 0 5px 0 5px;\"><strong>Reqs:</strong> " . $this->page->page_requests . "<span style=\"padding: 0 5px 0 5px;\">|</span>" . $created . "<span style=\"padding: 0 5px 0 5px;\">|</span>". $last_update . "</span>";
            } else {
                $dateStamp = '&nbsp;';
            }

        } else {

            if (!is_null($this->page)) {
                $dateStamp = "<span style=\"padding: 0 15px 0 15px;\"><strong>" . $this->_lang->__('Page Requests:') . "</strong> " . $this->page->page_requests;
                $created = ($this->page->created != '0000-00-00 00:00:00') ? '<strong>' . $this->_lang->__('Created On:') . '</strong> ' . date('l, M j, Y g:i A', strtotime($this->page->created)) : '<strong>' . $this->_lang->__('Created On:') . '</strong> ' . $this->_lang->__('Never');
                $last_update = ($this->page->updated != '0000-00-00 00:00:00') ? '<strong>' . $this->_lang->__('Last Updated:') . '</strong> ' . date('l, M j, Y g:i A', strtotime($this->page->updated)) : '<strong>' . $this->_lang->__('Last Updated:') . '</strong>' . $this->_lang->__('Never');
                $dateStamp = "<span style=\"padding: 0 15px 0 15px;\"><strong>" . $this->_lang->__('Page Requests:') . "</strong> " . $this->page->page_requests . "<span style=\"padding: 0 15px 0 15px;\">|</span>" . $created . "<span style=\"padding: 0 15px 0 15px;\">|</span>". $last_update . "</span>";
            } else {
                $dateStamp = '&nbsp;';
            }

        }

        $editorJS = null;
        $wrapBox = 'none';
        $cfg = new Phire_Table_Config();

        if ($cfg->settings['default_editor'] == 'CKEditor') {
            $editorJS = <<<EDITORJS

                            CKEDITOR.replace('page_content',
                                             {
                                                 filebrowserBrowseUrl : './browser.php?browser=ckeditor&type=file',
                                                 filebrowserImageBrowseUrl : './browser.php?browser=ckeditor&type=image',
                                                 filebrowserWindowWidth : '720',
                                                 filebrowserWindowHeight : '640'
                                             });

EDITORJS;
        } else if ($cfg->settings['default_editor'] == 'TinyMCE') {
            $editorJS = <<<EDITORJS

                            tinyMCE.init({
                                mode : "textareas",
                                theme : "advanced",
                                plugins : "emotions,spellchecker,advhr,insertdatetime,preview",
                                file_browser_callback : 'myFileBrowser',
                                convert_urls : false,

                                // Theme options
                                theme_advanced_buttons1 : "newdocument,|,bold,italic,underline,|,justifyleft,justifycenter,justifyright,fontselect,fontsizeselect,formatselect",
                                theme_advanced_buttons2 : "cut,copy,paste|,bullist,numlist,|,outdent,indent|,undo,redo,|,link,unlink,anchor,image,|,code,preview,|,forecolor,backcolor",
                                theme_advanced_buttons3 : "insertdate,inserttime,|,spellchecker,advhr,,removeformat,|,sub,sup,|,charmap,emotions",
                                theme_advanced_toolbar_location : "top",
                                theme_advanced_toolbar_align : "left",
                                theme_advanced_statusbar_location : "bottom"
                            });

EDITORJS;
        } else {
            $wrapBox = 'block';
        }

        $cont_edit = ($this->_postFields['cont_edit'] == 'Yes') ? "checked=\"checked\" " : '';

        $gen = $this->_lang->__('Generate new URL?');
        $addDate = $this->_lang->__('Add Date?');
        $back = $this->_lang->__('Back');
        $blue = $this->_lang->__('Blue fields are required.');
        $tme = $this->_lang->__('Time:');
        $pg_ct = $this->_lang->__('Page Content');
        $wrp = $this->_lang->__('Wrap');
        $int_acc = $this->_lang->__('Page Interaction & Access Settings');
        $pg_tgs = $this->_lang->__('Page Tags');
        $cnt_ed = $this->_lang->__('Continue Editing?');
        $chk_all = $this->_lang->__('Check All');
        $unchk_all = $this->_lang->__('Uncheck All');
        $inv = $this->_lang->__('Inverse');
        $cancel = $this->_lang->__('CANCEL');

        if (($this->_postFields['page_id'] != 0) && ($this->_postFields['site_id'] != 0) && (!is_null($this->_postFields['page_url']))) {
            $site = new Phire_Table_Sites();
            $site->findById($this->_postFields['site_id']);
            $page_link = "http://" . $site->site_domain . BASE_PATH . $this->_postFields['page_url'];
            if (($this->_postFields['published'] == 'Draft') && ($this->_postFields['site_id'] != 2001)) {
                $page_link .= '?draft=' . time();
            }
            $view = "<a href=\"{$page_link}\" target=\"_blank\">View</a> <span style=\"padding: 0 5px 0 5px;\">|</span> ";
            $generate = "                                    <br /><a id=\"generateLink\" class=\"smallLink\" href=\"#\" onclick=\"addPageFrm.convertPageURL('page_title', 'page_url', '" . $site->title_separator  . "'); xmlhttp.getRequest('../core/process/check.page.url.php?current=" . $this->_postFields['cur_page_url'] . "&url=' + addPageFrm.fo.page_url.value + '&site_id=' + addPageFrm.fo.site_id.value + '&section_id=' + addPageFrm.fo.section_id.value, addPageFrm.checkURL); return false;\">{$gen}</a><span style=\"font-size: 0.825em; padding: 0 5px 0 5px;\"> | </span><a id=\"dateLink\" class=\"smallLink\" href=\"#\" onclick=\"addPageFrm.addDateToURL(); return false;\">{$addDate}</a>";
        } else {
            $view = '';
            $generate = "                                    <br /><a id=\"dateLink\" class=\"smallLink\" href=\"#\" onclick=\"addPageFrm.addDateToURL(); return false;\">{$addDate}</a>";
        }

        if (!is_null($this->_postFields['plugin'])) {
            $plugin = "<input type=\"hidden\" name=\"plugin\" value=\"{$this->_postFields['plugin']}\" />";
            $plg_lnk = BASE_PATH . CONTENT_PATH . "/extensions/plugins/{$this->_postFields['plugin']}/?sys_path=" . BASE_PATH . SYS_PATH;
            $plg_cancel = "&plugin={$this->_postFields['plugin']}";
        } else {
            $plugin = null;
            $plg_lnk = './pages.php';
            $plg_cancel = null;
        }

        // Define the main form template.
        $this->_templates['main'] = <<<FORMTEMP
            <style type="text/css">
                .radioPad {
                    float: left;
                    margin: 0;
                    padding: 0 18px 0 4px;
                }
            </style>
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="{$plg_lnk}">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader">
                    <td class="grayHeader">
                        {$dateStamp}
                    </td>
                </tr>
                <tr>
                    <td style="padding: 15px 0 15px 0;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td class="textRight" colspan="4">
                                    <h4 style="float: left;">{$blue}</h4>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{template_id_label}]
                                </td>
                                <td class="textRight" colspan="4">
                                    <div id="templateDiv">
                                        [{template_id}]
                                    </div>
                                    [{site_id_label}]
                                    [{site_id}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{section_id_label}]
                                </td>
                                <td class="textRight">
                                    <div id="sectionDiv">
                                        [{section_id}]
                                    </div>
                                </td>
                                <td class="textRight">
                                    [{page_charset_label}]
                                </td>
                                <td>
                                    [{page_charset}]
                                </td>
                                <td class="textRight">
                                    [{page_robots_label}]
                                    [{page_robots}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="5">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                <td colspan="5" style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                    <strong style="font-size: 0.85em;">{$pg_ct}</strong>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    <br />
                                    [{page_title_label}]
                                </td>
                                <td colspan="4">
                                    <br />
                                    [{page_title}]
                                    <div id="pageTitleDiv">
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{page_url_label}]
                                </td>
                                <td colspan="4">
                                    [{page_url}]
{$generate}
                                    <div id="urlDiv">
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{page_author_label}]
                                </td>
                                <td colspan="4">
                                    [{page_author}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{page_keywords_label}]
                                </td>
                                <td colspan="4">
                                    [{page_keywords}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{page_desc_label}]
                                </td>
                                <td colspan="4">
                                    [{page_desc}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{pub_month_label}]
                                </td>
                                <td colspan="4">
                                    [{pub_month}]
                                    [{pub_day}]
                                    [{pub_year}]&nbsp; {$tme}
                                    [{pub_hour}]
                                    [{pub_min}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{exp_month_label}]
                                </td>
                                <td colspan="4">
                                    [{exp_month}]
                                    [{exp_day}]
                                    [{exp_year}]&nbsp; {$tme}
                                    [{exp_hour}]
                                    [{exp_min}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="5">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{editor_label}]
                                </td>
                                <td colspan="4">
                                <div id="wrapDiv" style="display: {$wrapBox};"><input onclick="addPageFrm.toggleWrap(this);" style="margin: 0 0 0 5px; padding: 0; float: right;" name="wrap" id="wrap" type="checkbox" class="checkBox" value="soft" checked="checked" /><span style="margin: 0 0 0 15px; padding: 0; float: right;">{$wrp}</span><a class="imagesBtn" title="Images" href="./browser.php?browser=native&type=image" onclick="brw.newWindow(this.href, 'browserWin', 600, 700, 'yes', 'yes', 'no', 'no', 'no', 'no'); return false;"><span class="hide">Images</span></a><a class="linksBtn" title="Links" href="./browser.php?browser=native&type=file" onclick="brw.newWindow(this.href, 'browserWin', 600, 700, 'yes', 'yes', 'no', 'no', 'no', 'no'); return false;"><span class="hide">Links</span></a></div>
                                    [{editor}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{page_content_label}]
                                </td>
                                <td id="pageContentTD" colspan="4">
                                    <div id="pageContentDiv">
                                        [{page_content}]
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{page_filter_label}]
                                </td>
                                <td colspan="4">
                                    <span class="right">
                                        [{page_access_label}]
                                        [{page_access}]
                                    </span>
                                    [{page_filter}]
                                    [{auto_links}]
                                </td>
                            </tr>[{page_tags_tmpl}]
                            <tr>
                                <td colspan="5">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                <td colspan="5" style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                    <strong style="font-size: 0.85em;">{$int_acc}</strong>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    <br />
                                    [{comments_allowed_label}]
                                </td>
                                <td>
                                    <br />
                                    [{comments_allowed}]
                                </td>
                                <td class="textRight">
                                    <br />
                                    [{feed_label}]
                                </td>
                                <td>
                                    <br />
                                    [{feed}]
                                </td>
                                <td class="textRight">
                                    <br />
                                    <span style="margin: 0 0 0 10px; padding: 0; display: block; float: right;">
                                        [{ssl_connection}]
                                    </span>
                                    [{ssl_connection_label}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    <br />
                                    [{flush_stats_label}]
                                </td>
                                <td>
                                    <br />
                                    [{flush_stats}]
                                </td>
                                <td class="textRight" colspan="2">
                                    &nbsp;
                                </td>
                                <td class="textRight">
                                    <br />
                                    <span style="margin: 0 0 0 10px; padding: 0; display: block; float: right;">
                                        [{published}]
                                    </span>
                                    [{published_label}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="5">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr>
                                <td colspan="5">
                                    <a style="margin: 0 0 0 10px; padding-top: 6px; height: 19px; font-size: 0.825em; float: right;" class="submitGrayBtn" href="../core/process/add.page.php?action=cancel{$plg_cancel}">{$cancel}</a> [{submit}] <span style="float: right; margin: 5px 15px 0 0; padding: 0; text-align: right;"><input style="float: right; margin: 0 0 0 8px; padding: 0;" type="checkbox" class="checkBox" name="cont_edit" id="cont_edit" value="Yes" {$cont_edit}/>{$view}{$cnt_ed}</span> [{page_id}] [{page_user_id}] [{cur_page_url}] {$plugin}
                                </td>
                            </tr>
                        </table>
                        <script type="text/javascript">
                            addPageFormInit();
                            var xmlhttp = new JaxXmlHttp();{$editorJS}
                        </script>
                    </td>
                </tr>
            </table>
FORMTEMP;

        // Define the tags form template.
        $this->_templates['tags'] = <<<TAGSTEMP

                            <tr>
                                <td colspan="5">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                <td colspan="5" style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                    <strong style="font-size: 0.85em;">{$pg_tgs}</strong>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    <br />
                                    [{page_form_tags_label}]<br />
                                    <a class="smallOrangeLink" href="#" onclick="addPageFrm.checkAll('page_form_tags'); return false;">[ {$chk_all} ]</a><br />
                                    <a class="smallOrangeLink" href="#" onclick="addPageFrm.uncheckAll('page_form_tags'); return false;">[ {$unchk_all} ]</a><br />
                                    <a class="smallOrangeLink" href="#" onclick="addPageFrm.checkInverse('page_form_tags'); return false;">[ {$inv} ]</a><br />
                                </td>
                                <td colspan="4" id="tagsTD" style="vertical-align: top;">
                                    <br />
                                    <div id="tagContainer">
                                        [{page_form_tags}]
                                    </div>
                                </td>
                            </tr>

TAGSTEMP;

        $mobile = (!is_null($this->_postFields['mobile'])) ? "<input type=\"hidden\" name=\"mobile\" value=\"true\" />" : null;

        // Define the mobile form template.
        $this->_templates['mobile'] = <<<FORMTEMP
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="./pages.php">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader" style="height; 16px;">
                    <td class="grayHeader" style="height; 16px;">
                        {$dateStamp}
                    </td>
                </tr>
                <tr>
                    <td style="padding: 5px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td>
                                    <h4>{$blue}</h4>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{template_id_label}]
                                </td>
                                <td>
                                    [{template_id}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{section_id_label}]
                                </td>
                                <td>
                                    [{section_id}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{page_charset_label}]
                                </td>
                                <td>
                                    [{page_charset}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{page_robots_label}]
                                </td>
                                <td>
                                    [{page_robots}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                <td colspan="2" style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                    <strong style="font-size: 0.85em;">{$pg_ct}</strong>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    <br />
                                    [{page_title_label}]
                                </td>
                                <td>
                                    <br />
                                    [{page_title}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{page_url_label}]
                                </td>
                                <td>
                                    [{page_url}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{page_author_label}]
                                </td>
                                <td>
                                    [{page_author}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{page_keywords_label}]
                                </td>
                                <td>
                                    [{page_keywords}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{page_desc_label}]
                                </td>
                                <td>
                                    [{page_desc}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{pub_month_label}]
                                </td>
                                <td>
                                    [{pub_month}]
                                    [{pub_day}]
                                    [{pub_year}]<br />
                                    {$tme}<br />
                                    [{pub_hour}]
                                    [{pub_min}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{exp_month_label}]
                                </td>
                                <td>
                                    [{exp_month}]
                                    [{exp_day}]
                                    [{exp_year}]<br />
                                    {$tme}<br />
                                    [{exp_hour}]
                                    [{exp_min}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{page_content_label}]
                                </td>
                                <td>
                                    [{page_content}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{page_filter_label}]
                                </td>
                                <td>
                                    [{page_filter}]
                                    [{auto_links}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{page_access_label}]
                                </td>
                                <td>
                                    [{page_access}]
                                </td>
                            </tr>[{page_tags_tmpl}]
                            <tr>
                                <td colspan="2">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                <td colspan="2" style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                    <strong style="font-size: 0.85em;">{$int_acc}</strong>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    <br />
                                    [{comments_allowed_label}]
                                </td>
                                <td>
                                    <br />
                                    [{comments_allowed}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{feed_label}]
                                </td>
                                <td>
                                    [{feed}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{ssl_connection_label}]
                                </td>
                                <td>
                                    [{ssl_connection}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{flush_stats_label}]
                                </td>
                                <td>
                                    [{flush_stats}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{published_label}]
                                </td>
                                <td>
                                    [{published}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    <a style="float: right; margin: 0 0 0 5px; padding: 2px 3px 4px 3px; height: 10px; font-size: 0.9em;" class="submitBtnGray" href="../../core/process/add.page.php?action=cancel&mobile=true">{$cancel}</a> [{submit}] <span style="float: right; margin: 5px 15px 0 0; padding: 0; text-align: right;"><input style="float: right; margin: 0 0 0 8px; padding: 0;" type="checkbox" class="checkBox" name="cont_edit" id="cont_edit" value="Yes" {$cont_edit}/>{$view}{$cnt_ed}</span> [{page_id}] [{page_user_id}] [{cur_page_url}] {$mobile} [{site_id}]
                                </td>
                            </tr>
                        </table>
                    </td>
                </tr>
            </table>
FORMTEMP;

        // Define the tags form template.
        $this->_templates['mobile_tags'] = <<<TAGSTEMP

                            <tr>
                                <td colspan="2">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                <td colspan="2" style="background-color: #eee; border-top: solid 1px #ccc; border-bottom: solid 1px #ccc;">
                                    <strong style="font-size: 0.85em;">{$pg_tgs}</strong>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    <br />
                                    [{page_form_tags_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    <br />
                                    [{page_form_tags}]
                                </td>
                            </tr>

TAGSTEMP;

    }

}
