<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Parser
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Parser
 *
 * @category   Phire
 * @package    Phire_Parser
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Parser
{

    /**
     * Content to evaluate
     * @var string
     */
    protected $_content = null;

    /**
     * URL request
     * @var string
     */
    protected $_url = null;

    /**
     * Constructor
     *
     * Instantiate the parser object.
     *
     * @param  string $content
     * @param  string $url
     * @return void
     */
    public function __construct($content, $url = null)
    {

        $this->_content = $content;
        $this->_url = $url;

        // Process the content through the default system parsers.
        $this->_content = Phire_Parser_Archive::init($this->_content, $this->_url)->getContent();
        $this->_content = Phire_Parser_Date::init($this->_content, $this->_url)->getContent();
        $this->_content = Phire_Parser_Event::init($this->_content, $this->_url)->getContent();
        $this->_content = Phire_Parser_Feed::init($this->_content, $this->_url)->getContent();
        $this->_content = Phire_Parser_Recent::init($this->_content, $this->_url)->getContent();
        $this->_content = Phire_Parser_Section::init($this->_content, $this->_url)->getContent();
        $this->_content = Phire_Parser_Session::init($this->_content, $this->_url)->getContent();
        $this->_content = Phire_Parser_Video::init($this->_content, $this->_url)->getContent();

    }

    /**
     * Static method to instantiate the parser object and
     * return itself to facilitate chaining methods together.
     *
     * @param  string $cont
     * @param  string $u
     * @return Phire_Parser
     */
    public static function getParser($cont, $u = null)
    {

        return new self($cont, $u);

    }

    /**
     * Set content within the content property.
     *
     * @param  string $subject
     * @param  string $replace
     * @return void
     */
    public function setContent($subject, $replace)
    {

        $this->_content = str_replace($subject, $replace, $this->_content);

    }

    /**
     * Get content within the content property.
     *
     * @return string
     */
    public function getContent()
    {

        return $this->_content;

    }

}
