<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Section
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Section
 *
 * @category   Phire
 * @package    Phire_Section
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Section
{

    /**
     * URL request
     * @var string
     */
    protected $_url = null;

    /**
     * Template type
     * @var string
     */
    protected $_type = null;

    /**
     * Template
     * @var string
     */
    protected $_tmpl = null;

    /**
     * Section content
     * @var string
     */
    protected $_section = null;

    /**
     * Section object
     * @var Phire_Table_Sections
     */
    protected $_section_object = null;

    /**
     * Section fields
     * @var array
     */
    protected $_section_fields = array();


    /**
     * Constructor
     *
     * Instantiate the section object.
     *
     * @param  int|string $id
     * @param  int|string $sid
     * @return void
     */
    public function __construct($id, $sid = null)
    {

        $lang = new Phire_Language();
        $this->_url = $id;

        if (!is_null($sid)) {
            $section = new Phire_Table_Sections();
            $section->getSection($this->_url, $sid);
        } else {
            $site = new Phire_Table_Sites();
            $site->getSite();
            $sid = $site->site_id;
            $section = new Phire_Table_Sections();
            $section->getSection($this->_url, $sid);
        }

        if ($section->default_title != '') {
            $title_sep = ($section->title_separator != '') ? $section->title_separator : ' ' ;
            $section_title = Moc10_String::setString($section->default_title . $title_sep . $section->section_title)->strip()->html();
            $section_sub_title = Moc10_String::setString($section->section_title)->strip()->html();
        } else {
            $section_title = Moc10_String::setString($section->section_title)->strip()->html();
            $section_sub_title = Moc10_String::setString($section->section_title)->strip()->html();
        }

        $site_email = (($section->site_email != '') ? "<a href=\"mailto:{$section->site_email}\">" . $lang->__('site administrator') . "</a>" : '');

        $this->_section_object = $section;
        $this->_section_object->execute("UPDATE " . DB_PREFIX . "sections SET section_requests = '" . ($this->_section_object->section_requests + 1) . "' WHERE section_id = '" . $this->_section_object->section_id . "' LIMIT 1");

        // Else initialize the section properties.
        $this->_section_fields = array('section_url' => BASE_PATH . $section->section_url,
                                       'section_title' => $section->section_title,
                                       'page_content' => $this->formatSection($site->site_pagination_limit, $site->site_pagination_range),
                                       'page_charset' => $section->charset,
                                       'page_title' => (string)$section_title,
                                       'page_sub_title' => (string)$section_sub_title,
                                       'page_author' => (string)Moc10_String::setString($section->default_author)->strip()->html(),
                                       'page_keywords' => (string)Moc10_String::setString($section->default_keywords)->strip()->html(),
                                       'page_desc' => (string)Moc10_String::setString($section->default_desc)->strip()->html(),
                                       'page_robots' => $section->robots,
                                       'site_domain' => $section->site_domain,
                                       'site_email' => $site_email,
                                       'site_tags' => Phire_TagCloud::render($section->site_id),
                                       'base_path' => BASE_PATH,
                                       'sys_path' => SYS_PATH,
                                       'content_path' => CONTENT_PATH);

        $this->_type = $section->type;

        // Handle any mobile presentation, if applicable.
        $mob = new Moc10_Session_Mobile();
        if (($mob->isMobile !== false) && ($section->mobile_template != '')) {
            $this->_tmpl = $section->mobile_template;
        } else {
            $this->_tmpl = $section->template;
        }

    }

    /**
     * Set method to set the property to the value of _section_fields[$name].
     *
     * @param  string $name
     * @param  mixed $value
     * @throws Exception
     * @return void
     */
    public function __set($name, $value)
    {

        // Check to see if the field key exists.
        if (!array_key_exists($name, $this->_section_fields)) {
            throw new Exception("The field '" . $name . "' does not exist.");
        } else {
            $this->_section_fields[$name] = $value;
        }

    }

    /**
     * Get method to return the value of _section_fields[$name].
     *
     * @param  string $name
     * @throws Exception
     * @return mixed
     */
    public function __get($name)
    {

        // Check to see if the field key exists.
        if (!array_key_exists($name, $this->_section_fields)) {
            throw new Exception("The field '" . $name . "' does not exist.");
        } else {
            return $this->_section_fields[$name];
        }

    }

    /**
     * Output the section as is.
     *
     * @return string
     */
    public function __toString()
    {

        return $this->_section;

    }

    /**
     * Format section
     *
     * @param  int|string $ste_pg
     * @param  int|string $ste_pg_rg
     * @return string
     */
    public function formatSection($ste_pg, $ste_pg_rg)
    {

        $sess = Moc10_Session::getInstance();
        $lang = new Phire_Language();
        $pg = (isset($_GET['page'])) ? $_GET['page'] : 1;

        $section_format = '';
        $section_count = 0;
        $date_format = $this->_section_object->default_date_format;
        $time_format = ($this->_section_object->default_time_format != '') ? ' ' . $this->_section_object->default_time_format : '';
        $limit = ($this->_section_object->long_limit > 0) ? $this->_section_object->long_limit : null;

        $section_header = "[{page_links}]\n";
        $section_header .= ($this->_section_object->long_template_container != 'None') ? str_replace(">", " id=\"sectionLong{$this->_section_object->section_id}\">\n", $this->_section_object->long_template_container) : '';

        $sort = explode('|', $this->_section_object->sort_order);

        if (stripos($sort[1], 'Today') !== false) {
            $sortOrder = substr($sort[1], 0, strpos($sort[1], ' '));
            $dateLimit = null;
            if (stripos($sort[1], '>=') !== false) {
                $dateLimit = ' AND [{date_marker}] >= CURDATE()';
            } else {
                $dateLimit = ' AND [{date_marker}] <= CURDATE()';
            }
        } else {
            $sortOrder = $sort[1];
            $dateLimit = null;
        }

        // Set sort order.
        switch ($sort[0]) {
            case 'ID':
                if ($sortOrder != 'RAND()') {
                    $sort_page = 'page_id ' . $sortOrder;
                    $sort_file = 'file_id ' . $sortOrder;
                    $sort_image = 'image_id ' . $sortOrder;
                    $sort_event = 'event_id ' . $sortOrder;
                } else {
                    $sort_page = $sortOrder;
                    $sort_file = $sortOrder;
                    $sort_image = $sortOrder;
                    $sort_event = $sortOrder;
                }
                break;

            case 'Title':
                if ($sortOrder != 'RAND()') {
                    $sort_page = 'page_title ' . $sortOrder;
                    $sort_file = 'file_title ' . $sortOrder;
                    $sort_image = 'image_title ' . $sortOrder;
                    $sort_event = 'event_title ' . $sortOrder;
                } else {
                    $sort_page = $sortOrder;
                    $sort_file = $sortOrder;
                    $sort_image = $sortOrder;
                    $sort_event = $sortOrder;
                }
                break;

            case 'Date':
                if ($sortOrder != 'RAND()') {
                    $sort_page = 'created ' . $sortOrder;
                    $sort_file = 'file_updated ' . $sortOrder;
                    $sort_image = 'image_updated ' . $sortOrder;
                    $sort_event = 'event_start_date, event_start_time ' . $sortOrder;
                } else {
                    $sort_page = $sortOrder;
                    $sort_file = $sortOrder;
                    $sort_image = $sortOrder;
                    $sort_event = $sortOrder;
                }
                break;

        }

        // Get any pages within the section.
        if (isset($sess->member_id)) {
            $sql = "SELECT * FROM " . DB_PREFIX . "pages WHERE section_id = '{$this->_section_object->section_id}' AND published = 'Yes'" . str_replace('[{date_marker}]', 'created', $dateLimit) . " ORDER BY " . $sort_page;
        } else {
            $sql = "SELECT * FROM " . DB_PREFIX . "pages WHERE section_id = '{$this->_section_object->section_id}' AND published = 'Yes' AND page_access = 'Public'" . str_replace('[{date_marker}]', 'created', $dateLimit) . " ORDER BY " . $sort_page;
        }
        $sql .= ($limit != 0) ? " LIMIT {$limit}" : '';
        $pages = new Phire_Table_Pages();
        $pages->execute($sql);

        // Get any files within the section.
        $files = new Phire_Table_Files();
        $files->findAll($sort_file, 'section_id', $this->_section_object->section_id, $limit);

        // Get any images within the section.
        $images = new Phire_Table_Images();
        $images->findAll($sort_image, 'section_id', $this->_section_object->section_id, $limit);

        // Get any events within the section.
        if (isset($sess->member_id)) {
            $sql = "SELECT * FROM " . DB_PREFIX . "events WHERE section_id = '{$this->_section_object->section_id}'" . str_replace('[{date_marker}]', 'event_start_date', $dateLimit) . " ORDER BY " . $sort_event;
        } else {
            $sql = "SELECT * FROM " . DB_PREFIX . "events WHERE section_id = '{$this->_section_object->section_id}' AND event_access = 'Public'" . str_replace('[{date_marker}]', 'event_start_date', $dateLimit) . " ORDER BY " . $sort_event;
        }
        $sql .= ($limit != 0) ? " LIMIT {$limit}" : '';
        $events = new Phire_Table_Events();
        $events->execute($sql);

        $section_row_tmpl = $this->_section_object->long_template;
        $section_rows = array();

        // If pages found, format and set in content.
        if (isset($pages->rows[0])) {
            $section_count++;
            $item_count = 0;
            foreach ($pages->rows as $val) {
                $item_count++;
                $stripped_content = preg_replace('/\[\{(.*?)\}\]/', '', $val['page_content']);

                $sectAry = array('page_url' => BASE_PATH . $val['page_url'],
                                 'page_title' => $val['page_title'],
                                 'page_sub_title' => $val['page_title'],
                                 'page_author' => $val['page_author'],
                                 'page_keywords' => $val['page_keywords'],
                                 'page_desc' => $val['page_desc'],
                                 'page_content' => (string)Moc10_String::setString($stripped_content)->striptags(),
                                 'page_created' => (string)Moc10_String::setString($val['created'])->date($date_format . $time_format),
                                 'page_updated' => (string)Moc10_String::setString($val['updated'])->date($date_format . $time_format),
                                 'site_domain' => $this->_section_object->site_domain,
                                 'base_path' => BASE_PATH,
                                 'sys_path' => SYS_PATH,
                                 'content_path' => CONTENT_PATH,
                                 'count' => $item_count);

                $matches = array();
                preg_match_all('/\[\{page_content_\d*\}\]/', $section_row_tmpl, $matches);
                if (isset($matches[0][0])) {
                    foreach ($matches[0] as $v) {
                        $sub = str_replace('[{page_content_', '', $v);
                        $sub = str_replace('}]', '', $sub);
                        $sectAry['page_content_' . $sub] = substr(trim(strip_tags($stripped_content)), 0, $sub) . '...';
                    }
                }

                $section_rows[] = $sectAry;

            }

        }

        // If files found, format and set in content.
        if (isset($files->rows[0])) {
            $section_count++;
            $item_count = 0;
            foreach ($files->rows as $val) {
                $item_count++;
                if ((stripos($val['file_name'], '.jpg') !== false) || (stripos($val['file_name'], '.jpeg') !== false) || (stripos($val['file_name'], '.jpe') !== false) || (stripos($val['file_name'], '.gif') !== false) || (stripos($val['file_name'], '.png') !== false)) {
                     $fle = new Moc10_Image($this->_section_object->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/files/' . $val['file_name']);
                     $width = $fle->width;
                     $height = $fle->height;
                } else {
                    $width = null;
                    $height = null;
                }
                $section_rows[] = array('file_name' => $val['file_name'],
                                        'file_title' => $val['file_title'],
                                        'file_desc' => $val['file_desc'],
                                        'width' => $width,
                                        'height' => $height,
                                        'file_updated' => (string)Moc10_String::setString($val['file_updated'])->date($date_format . $time_format),
                                        'site_domain' => $this->_section_object->site_domain,
                                        'base_path' => BASE_PATH,
                                        'sys_path' => SYS_PATH,
                                        'content_path' => CONTENT_PATH,
                                        'count' => $item_count);
            }
        }

        // If images found, format and set in content.
        if (isset($images->rows[0])) {
            $section_count++;
            $item_count = 0;
            foreach ($images->rows as $val) {
                $item_count++;
                $lg_width = null;
                $lg_height = null;
                $md_width = null;
                $md_height = null;
                $sm_width = null;
                $sm_height = null;
                if (file_exists($this->_section_object->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $val['image_name'])) {
                    $lg = new Moc10_Image($this->_section_object->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $val['image_name']);
                    $lg_width = $lg->width;
                    $lg_height = $lg->height;
                }
                if (file_exists($this->_section_object->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $val['image_name'])) {
                    $md = new Moc10_Image($this->_section_object->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $val['image_name']);
                    $md_width = $md->width;
                    $md_height = $md->height;
                }
                if (file_exists($this->_section_object->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $val['image_name'])) {
                    $sm = new Moc10_Image($this->_section_object->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $val['image_name']);
                    $sm_width = $sm->width;
                    $sm_height = $sm->height;
                }
                $section_rows[] = array('image_name' => $val['image_name'],
                                        'image_title' => $val['image_title'],
                                        'image_caption' => $val['image_caption'],
                                        'file_updated' => (string)Moc10_String::setString($val['image_updated'])->date($date_format . $time_format),
                                        'large_width' => $lg_width,
                                        'large_height' => $lg_height,
                                        'medium_width' => $md_width,
                                        'medium_height' => $md_height,
                                        'small_width' => $sm_width,
                                        'small_height' => $sm_height,
                                        'site_domain' => $this->_section_object->site_domain,
                                        'base_path' => BASE_PATH,
                                        'sys_path' => SYS_PATH,
                                        'content_path' => CONTENT_PATH,
                                        'count' => $item_count);
            }
        }

        // If events found, format and set in content.
        if (isset($events->rows[0])) {
            $section_count++;
            if ($time_format == '') {
                $tf = 'g:i A';
            } else {
                $tf = $time_format;
            }
            $item_count = 0;
            foreach ($events->rows as $val) {

                $item_count++;

                if ($val['event_start_date'] != '0000-00-00') {
                    $evt_start = Moc10_String::setString($val['event_start_date'])->date($date_format);
                } else {
                    $rec = Moc10_String::setString($val['event_recurrence'])->split('+');
                    $evt_start = $rec[0] . ' ' . $rec[1] . ' of the Month';
                }

                if (($val['state'] != '--') && ($val['state'] != '')) {
                    $st = $val['state'];
                } else {
                    $st = '';
                }

                if ($val['country'] != '--') {
                    $cnty = $val['country'];
                } else {
                    $cnty = '';
                }

                $section_rows[] = array('event_id' => $val['event_id'],
                                        'event_title' => $val['event_title'],
                                        'event_url' => BASE_PATH . '/event/' . $val['event_id'] . Moc10_String::setString($val['event_title'])->slug(),
                                        'event_start_date' => $evt_start,
                                        'event_end_date' => ($val['event_end_date'] != '0000-00-00') ? ' - ' . Moc10_String::setString($val['event_end_date'])->date($date_format) : null,
                                        'event_start_time' => Moc10_String::setString($val['event_start_time'])->date($tf),
                                        'event_end_time' => ($val['event_end_time'] != '00:00:00') ? ' - ' . Moc10_String::setString($val['event_end_time'])->date($tf) : null,
                                        'address1' => $val['address1'],
                                        'address2' => $val['address2'],
                                        'city' => $val['city'],
                                        'state' => $st,
                                        'zip' => $val['zip'],
                                        'country' => $cnty,
                                        'phone' => $val['phone'],
                                        'event_link' => $val['event_link'],
                                        'event_desc' => $val['event_desc'],
                                        'count' => $item_count);

            }
        }

        $section_footer = ($this->_section_object->long_template_container != 'None') ? str_replace("<", "</", $this->_section_object->long_template_container) . "\n" : '';
        $section_footer .= "\n[{page_links}]\n";

        // Detect any child sections of this section.
        $childOrderAry = explode('|', $this->_section_object->sort_order);
        if ($childOrderAry[0] == 'Title') {
            $childOrder = 'section_title ' . (($childOrderAry[1] != 'RAND()') ? substr($childOrderAry[1], 0, strpos($childOrderAry[1], ' ')) : 'ASC');
        } else if (($childOrderAry[0] == 'ID') || ($childOrderAry[0] == 'Date')) {
            $childOrder = 'section_id ' . (($childOrderAry[1] != 'RAND()') ? substr($childOrderAry[1], 0, strpos($childOrderAry[1], ' ')) : 'ASC');
        }
        $childSections = new Phire_Table_Sections();
        $childSections->findAll($childOrder, 'parent_section_id', $this->_section_object->section_id);
        $isChild = false;
        $chSects = null;

        if (isset($childSections->rows[0])) {
            foreach($childSections->rows as $child) {
                if ($child->section_id != $this->_section_object->section_id) {
                    $chSects .= "[{section_{$child->section_id}}]\n";
                    $isChild = true;
                }
            }
            if ($isChild) {
                $chSects = Phire_Parser_Section::init($chSects, $this->_url)->getContent();
            }
        }

        if ($section_count == 0)  {
            if (is_null($chSects)) {
                $section_format = "<div id=\"sectionLong{$this->_section_object->section_id}\">\n    <p>" . $lang->__('There is currently no content in this section.') . "</p>\n</div>\n";
            }
        } else {
            // Get the site pagination limit.
            $pg_num = (($ste_pg != 0) && ($this->_section_object->paginate == 'Yes')) ? $ste_pg : count($section_rows);
            $pg_range = ($ste_pg_rg != 0) ? $ste_pg_rg : null;

            // Render the page results.
            $sess->section = new Moc10_Session_Paginator($section_rows, $pg_num, $pg_range);
            $sess->section->setHeader($section_header);
            $sess->section->setRowTemplate($section_row_tmpl);
            $sess->section->setFooter($section_footer);
            $section_format = $sess->section->render($pg, ' | ', 'subLinkOn', 'subLinkOff', null, true);
            $section_format = str_replace('[{section_url}]', BASE_PATH . $this->_section_object->section_url, $section_format);
            $section_format = str_replace('[{section_title}]', $this->_section_object->section_title, $section_format);

        }

        $section_format = str_replace('&query=' . $this->_section_object->section_url, '', $section_format);
        $section_format = str_replace('index.php', substr($this->_section_object->section_url, 1), $section_format);

        if (($isChild) && (!is_null($chSects))) {
            $section_format .= $chSects;
        }

        return $section_format;

    }

    /**
     * Set content within the section.
     *
     * @param  string $subject
     * @param  string $replace
     * @return void
     */
    public function setContent($subject, $replace)
    {

        $this->_section = str_replace($subject, $replace, $this->_section);

    }

    /**
     * Initialize the section.
     *
     * @return void
     */
    public function init()
    {

        $this->_section = Phire_Parser_Template::init($this->_tmpl)->getContent();

        foreach ($this->_section_fields as $key => $value) {
            $this->setContent('[{' . $key . '}]', $value);
        }

        $page_matches = array();
        preg_match_all('/\[\{page_\d*\}\]/', $this->_section, $page_matches);

        if (isset($page_matches[0][0])) {
            foreach ($page_matches[0] as $value) {
                $str = substr($value, strpos($value, '[{page_') + 7);
                $id = substr($str, 0, strpos($str, '}'));
                $placeholder = '[{page_' . $id . '}]';
                $pg = new Phire_Table_Pages();
                $pg->findById($id);
                if (isset($pg->page_id)) {
                    $pg_cont = (isset($pg->page_id)) ? $pg->page_content : '';
                } else {
                    $pg_cont = '';
                }
                $this->_section = str_replace($placeholder, $pg_cont, $this->_section);
            }
        }

        $this->_section = Phire_Parser::getParser($this->_section)->getContent();

    }

    /**
     * Render the section.
     *
     * @return void
     */
    public function render()
    {

        $sess = Moc10_Session::getInstance();

        // If the section is private, redirect to the member login page.
        if (($this->_section_object->section_access == 'Private') && ((!isset($sess->member_id)) && (!isset($sess->user_id)))) {

            header('Location: /member/login');

        // Else, render the section.
        } else {


            if (!headers_sent()) {
                header('Content-type: ' . $this->_type);
            }

            $section_content = Phire_Plugins::init($this->_section, $this->_url, $this->_section_object->site_id, false, $this->_section_object->section_id)->getContent();

            if (strpos($section_content, '[{on}]') !== false) {
                $nav_matches = array();
                preg_match_all('/\[\{on\}\]/', $section_content, $nav_matches, PREG_OFFSET_CAPTURE);
                if (isset($nav_matches[0][0])) {
                    $swapAry = array();
                    foreach ($nav_matches[0] as $on) {
                        $href = substr($section_content, ($on[1] + 14));
                        $href = substr($href, 0, strpos($href, '"'));
                        $str = substr($section_content, $on[1]);
                        $str = substr($str, 0, (strpos($str, '>') + 1));
                        if ($href == substr($_SERVER['REQUEST_URI'], 0, strlen($href))) {
                            $swap = str_replace('[{on}]', 'On', $str);
                        } else {
                            $swap = str_replace('[{on}]', '', $str);
                        }
                        $swapAry[] = array($str, $swap);
                    }
                    if (count($swapAry) > 0) {
                        foreach ($swapAry as $swp) {
                            $section_content = str_replace($swp[0], $swp[1], $section_content);
                        }
                    }
                }
            }

            print($section_content);

        }

    }

    /**
     * Get the section type.
     *
     * @return string
     */
    public function getSectionType()
    {

        return $this->_type;

    }

    /**
     * Get the section.
     *
     * @return string
     */
    public function getSection()
    {

        return $this->_section;

    }

}
