<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Table
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Table_SearchLog
 *
 * @category   Phire
 * @package    Phire_Table
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Table_SearchLog extends Moc10_Record
{

    /**
     * Table name of the database table
     * @var string
     */
    protected $_tableName = 'searchlog';

    /**
     * Primary ID field name of the database table
     * @var string
     */
    protected $_primaryId = 'search_id';

    /**
     * Constructor
     *
     * Instantiate the database record object.
     *
     * @param array  $fields
     * @param string $type
     * @param string $dbase
     * @param string $host
     * @param string $user
     * @param string $pass
     * @throws Exception
     * @return void
     */
    public function __construct($fields = null, $type = null, $db = null, $host = null, $user = null, $pass = null)
    {

        if (!isset($this->_tableName)) {
            throw new Exception('Error: Table name not set.');
        } else {
            $this->_tableName = DB_PREFIX . $this->_tableName;
            parent::__construct($fields, $type, $db, $host, $user, $pass);
        }

    }


    /**
     * Get search count of a site
     *
     * @param  int|string $sid
     * @return int
     */
    public function getCount($sid)
    {

        $searchCountAry = array();
        $sites = new Phire_Table_Sites();
        $sites->execute("SELECT site_id, COUNT(*) as search_count from " . DB_PREFIX . "searchlog GROUP BY site_id");

        if (isset($sites->rows[0])) {
            foreach ($sites->rows as $site) {
                $searchCountAry[$site->site_id] = $site->search_count;
            }
        }

        return (isset($searchCountAry[$sid])) ? $searchCountAry[$sid] : 0;

    }

}
