<?php
/**
 * Moc10 Library
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.moc10phplibrary.com/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@moc10media.com so we can send you a copy immediately.
 *
 * @category   Moc10
 * @package    Moc10_Array
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.moc10phplibrary.com/LICENSE.TXT     New BSD License
 */

/**
 * Moc10_Array
 *
 * @category   Moc10
 * @package    Moc10_Array
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.moc10phplibrary.com/LICENSE.TXT     New BSD License
 * @version    1.9.7
 */

class Moc10_Array extends ArrayObject
{

    /**
     * Array props property
     * @var boolean
     */
    protected $_props = false;

    /**
     * Search property
     * @var string
     */
    protected $_search = null;

    /**
     * Case search property
     * @var boolean
     */
    protected $_case = false;

    /**
     * Search pattern property
     * @var string
     */
    protected $_pattern = 'all';

    /**
     * Constructor
     *
     * Instantiate the array object.
     *
     * @param  array $arr
     * @param  boolean $props
     * @return void
     */
    public function __construct($arr = null, $props = false)
    {

        $this->_props = $props;

        if ($this->_props) {
            parent::__construct((is_null($arr) ? array() : $arr), ArrayObject::ARRAY_AS_PROPS);
        } else {
            parent::__construct((is_null($arr) ? array() : $arr));
        }

    }

    /**
     * Static method to instantiate the array object and return itself
     * to facilitate chaining methods together.
     *
     * @param  array $arr
     * @param  boolean $props
     * @return Moc10_Array
     */
    public static function setArray($arr = null, $props = false)
    {

        return new self($arr, $props);

    }

    /**
     * Method to perform a search over the array and return an array of the results.
     *
     * @param  string  $search
     * @param  boolean $case
     * @param  string $preserve
     * @return int
     */
    public function search($search, $case = false, $preserve = 'ARRAY')
    {

       $this->_case = $case;

        if (substr($search, 0, 1) == '*') {
            $this->_pattern = 'back';
            $this->_search = substr($search, 1);
        } else if (substr($search, -1) == '*') {
            $this->_pattern = 'front';
            $this->_search = substr($search, 0, -1);
        } else {
            $this->_pattern = 'all';
            $this->_search = $search;
        }

        // Execute the array filter to search the array.
        $found = array_filter((array)$this, array($this, '_searchArray'));

        switch ($preserve) {

            // Return as an array.
            case 'ARRAY':
                return $found;
                break;

            // Return as an array object.
            case 'ARRAY_OBJECT':
                return ($this->_props) ? new ArrayObject($found, ArrayObject::ARRAY_AS_PROPS) : new ArrayObject($found);
                break;

            // Return as itself, overwriting the values of the array with the new results.
            case 'SELF':
                return new self($found, $this->_props);
                break;

        }

    }

    /**
     * Method to search an array for a string, non-inclusive.
     *
     * @param  string $val
     * @return string
     */
    protected function _searchArray($val)
    {

        // If case sensitive.
        if ($this->_case) {

            switch ($this->_pattern) {
                // For 'string*'
                case 'front':
                    if (substr($val, 0, strlen($this->_search)) == $this->_search) {
                        return $val;
                    }
                    break;

                // For '*string'
                case 'back':
                    if (substr($val, (0 - strlen($this->_search)), strlen($this->_search)) == $this->_search) {
                        return $val;
                    }
                    break;

                // For 'string' (all-inclusive)
                case 'all':
                    if (strpos($val, $this->_search) !== false) {
                        return $val;
                    }
                    break;
            }

        // Else, case insensitive.
        } else {

            switch ($this->_pattern) {
                // For 'string*'
                case 'front':
                    if (substr(strtolower($val), 0, strlen($this->_search)) == strtolower($this->_search)) {
                        return $val;
                    }
                    break;

                // For '*string'
                case 'back':
                    if (substr(strtolower($val), (0 - strlen($this->_search)), strlen($this->_search)) == strtolower($this->_search)) {
                        return $val;
                    }
                    break;

                // For 'string' (all-inclusive)
                case 'all':
                    if (stripos($val, $this->_search) !== false) {
                        return $val;
                    }
                    break;
            }

        }

    }

}
