<?php

/**
 * Phire Edit Image
 *
 * @category   Phire
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

set_time_limit(0);
require_once '../../bootstrap.php';

try {

    // Retrieve session and check if the edit image action has been cancelled, clearing out any related session data.
    $sess = Moc10_Session::getInstance();

    if ((isset($_GET['action'])) && ($_GET['action'] == 'cancel')) {

        unset($sess->image_error);
        unset($sess->edit_image_form);

        if (isset($_GET['plugin'])) {
            header('Location: ' . BASE_PATH . CONTENT_PATH . '/extensions/plugins/' . $_GET['plugin'] . '/?sys_path=' . BASE_PATH . SYS_PATH);
        } else {
            header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_GET['mobile'])) ? 'mobile/' : '') . 'assets/images.php');
        }

    // Else, get the POST data and validate the form.
    } else {

        unset($sess->edit_image_form);
        unset($sess->image_error);

        $form = new Phire_Form_EditImage(BASE_PATH . SYS_PATH . '/core/process/edit.image.php?iid=' . $_POST['image_id'], 'post', '        ');
        $form->init($_POST, $_POST['current_image_name']);

        // If the form is valid, process the image.
        if ($form->isValid()) {

            $img = new Phire_Table_Images();
            $img->findById($_POST['image_id']);

            $old_site = new Phire_Table_Sites();
            $old_site->findById($img->site_id);

            $new_site = new Phire_Table_Sites();
            $new_site->findById($_POST['site_id']);

            if ($_FILES['image_name']['name'] != '') {
                $path_parts = pathinfo($_FILES['image_name']['name']);

                // Check the site for any file format restrictions.
                if ($new_site->allowed_image_formats != 'All') {
                    $allowed_types = explode('|', $new_site->allowed_image_formats);
                    if (!isset($path_parts['extension']) || !in_array(strtolower($path_parts['extension']), $allowed_types)) {
                        $sess->image_error = (!isset($path_parts['extension'])) ? "<div class=\"error\">" . $lang->__('There was no defined extension for that image.') . "</div>\n" : "<div class=\"error\">" . $lang->__('The %1 image format is not allowed.', strtoupper($path_parts['extension'])) . "</div>\n";
                    }
                }

            }

            // If a image is passed that isn't allowed, return with the error.
            if (isset($sess->image_error)) {
                $sess->edit_image_form = $form;
                 header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_POST['mobile'])) ? 'mobile/' : '') . 'assets/edit-image.php?iid=' . $_POST['image_id']);
            // Else, finish processing the image.
            } else {
                unset($sess->edit_image_form);
                unset($sess->image_error);

                // Check the image size against the max allowed image size.
                $image_max_size = null;

                if (strpos($new_site->image_max_size, 'MB') !== false) {
                    $image_max_size = str_replace(' MB', '000000', $new_site->image_max_size);
                } else {
                    $image_max_size = str_replace(' KB', '000', $new_site->image_max_size);
                }

                if ($_FILES['image_name']['name'] != '') {

                    // Delete any old image files.
                    if (file_exists($old_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $_POST['current_image_name'])) {
                        unlink($old_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $_POST['current_image_name']);
                    }
                    if (file_exists($old_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $_POST['current_image_name'])) {
                        unlink($old_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $_POST['current_image_name']);
                    }
                    if (file_exists($old_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $_POST['current_image_name'])) {
                        unlink($old_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $_POST['current_image_name']);
                    }

                    if (file_exists($new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $_POST['current_image_name'])) {
                        unlink($new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $_POST['current_image_name']);
                    }
                    if (file_exists($new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $_POST['current_image_name'])) {
                        unlink($new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $_POST['current_image_name']);
                    }
                    if (file_exists($new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $_POST['current_image_name'])) {
                        unlink($new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $_POST['current_image_name']);
                    }

                    // Check for duplicate images and rename accordingly.
                    $newimage = $_FILES['image_name']['name'];
                    $path_parts = pathinfo($newimage);
                    $orgfile = $path_parts['filename'];
                    $ext = (isset($path_parts['extension'])) ? $path_parts['extension'] : 'NO_EXT';
                    $i = 1;

                    while (file_exists($new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $newimage)) {
                        $newimage = $orgfile . '_' . $i . '.' . $ext;
                        $i++;
                    }

                    if ($ext != 'NO_EXT') {

                        // Process the new file upload.
                        $image = new Moc10_Image_Upload($_FILES['image_name']['tmp_name'], $new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $newimage, $image_max_size);
                        $img->image_name = $newimage;
                        unset($sess->image_error);

                        // Process the large image.
                        if ($new_site->large_action != 'None') {
                            switch ($new_site->large_action) {
                                case 'Crop':
                                    $image->crop($new_site->large_size);
                                    break;
                                case 'Resize':
                                    $image->resize($new_site->large_size);
                                    break;
                                case 'Scale':
                                    $image->scale(($new_site->large_size / 100));
                                    break;
                            }
                        }

                        // Process the medium image.
                        if ($new_site->medium_action != 'None') {
                            switch ($new_site->medium_action) {
                                case 'Crop':
                                    $image->crop($new_site->medium_size, 0, 0, null, $new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $newimage);
                                    break;
                                case 'Resize':
                                    $image->resize($new_site->medium_size, null, $new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $newimage);
                                    break;
                                case 'Scale':
                                    $image->scale(($new_site->medium_size / 100), null, $new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $newimage);
                                    break;
                            }
                        }

                        // Process the small image.
                        if ($new_site->small_action != 'None') {
                            switch ($new_site->small_action) {
                                case 'Crop':
                                    $image->crop($new_site->small_size, 0, 0, null, $new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $newimage);
                                    break;
                                case 'Resize':
                                    $image->resize($new_site->small_size, null, $new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $newimage);
                                    break;
                                case 'Scale':
                                    $image->scale(($new_site->small_size / 100), null, $new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $newimage);
                                    break;
                            }
                        }
                    } else {
                        $sess->image_error = "<div class=\"error\">" . $lang->__('That image format is not allowed.') . "</div>\n";
                    }

                } else {
                    // Check for duplicate files and rename accordingly.
                    $newimage = $img->image_name;
                    // Move image to the new site if applicable.
                    if ($img->site_id != $_POST['site_id']) {
                        $path_parts = pathinfo($newimage);
                        $orgfile = $path_parts['filename'];
                        $ext = (isset($path_parts['extension'])) ? $path_parts['extension'] : 'NO_EXT';
                        $i = 1;

                        while (file_exists($new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $newimage)) {
                            $newimage = $orgfile . '_' . $i . '.' . $ext;
                            $i++;
                        }
                        if ($ext != 'NO_EXT') {
                            if (file_exists($old_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $img->image_name)) {
                                $small = new Moc10_File($old_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $img->image_name);
                                $small->move($new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $newimage);
                            }
                            if (file_exists($old_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $img->image_name)) {
                                $medium = new Moc10_File($old_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $img->image_name);
                                $medium->move($new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $newimage);
                            }
                            if (file_exists($old_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $img->image_name)) {
                                $large = new Moc10_File($old_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $img->image_name);
                                $large->move($new_site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $newimage);
                            }
                            unset($sess->image_error);
                        } else {
                            $sess->image_error = "<div class=\"error\">" . $lang->__('That image format is not allowed.') . "</div>\n";
                        }
                    }
                    $img->image_name = $newimage;
                }

                if (isset($sess->image_error)) {
                    $sess->edit_image_form = $form;
                } else {

                    // Edit the image in the system.
                    $img->site_id = $_POST['site_id'];
                    $img->user_id = ($img->user_id == 0) ? $sess->user_id : $img->user_id;
                    $img->section_id = $_POST['section_id'];
                    $img->image_title = (($_POST['image_title'] != '') ? $_POST['image_title'] : $img->image_name);
                    $img->image_caption = (($_POST['image_caption'] != '') ? $_POST['image_caption'] : $img->image_name);
                    $img->image_updated = date('Y-m-d H:i:s');
                    $img->save();

                    // Return.
                    if ((isset($_POST['plugin'])) && (!is_null($_POST['plugin']))) {
                        header('Location: ' . BASE_PATH . CONTENT_PATH . '/extensions/plugins/' . $_POST['plugin'] .'/?action=saved&sys_path=' . BASE_PATH . SYS_PATH);
                    } else {
                        header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_POST['mobile'])) ? 'mobile/' : '') . 'assets/images.php?action=saved');
                    }

                }

            }

        // Else, set the form into a session variable and return.
        } else {

            $sess->edit_image_form = $form;
            header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_POST['mobile'])) ? 'mobile/' : '') . 'assets/edit-image.php?iid=' . $_POST['image_id']);

        }

    }

// Else throw a exception/error.
} catch (Exception $e) {

    include_once 'init.php';
    include_once '../includes/error.header.php';
    print("        <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 0 0;\">" . $e->getMessage() . "</p>\n");
    include_once '../includes/footer.php';

}

?>
