<?php

/**
 * Phire Get Config
 *
 * @category   Phire
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

require_once dirname(__FILE__) . '/config.check.php';

try {

    // Initialize variables for configuration and system checks.
    $server = new Moc10_Session_Server();
    $sync_error_msg = '';
    $mysqlVersionAry = array();
    $system_docroot = $_SERVER['DOCUMENT_ROOT'];
    $os = ($server->distro != 'Unknown') ? $server->os . ' (' . $server->distro . ')' : $server->os;

    $mysqlVersionAry = explode('-', Moc10_Db::getInstance()->interface->version());

    $on = $lang->__('On');
    $off = $lang->__('Off');
    $yes = $lang->__('Yes');
    $no = $lang->__('No');
    $never = $lang->__('Never');
    $setzero = $lang->__('Set to zero to disable.');
    $lastopt = $lang->__('Last Optimized:');
    $attempted = $lang->__('Attempted Logins');
    $failed = $lang->__('Failed/Blocked Logins');
    $successful = $lang->__('Successful Logins');
    $none = $lang->__('None (Not recommended)');

    // Get system configuration values.
    $config = new Phire_Table_Config();
    $config->findAll();

    // Print the table header.
    print <<<TABLEHEADER
        <style type="text/css">
            .checkPad { font-size: 1.0em; }
        </style>
        <form id="configForm" action="../core/process/update.config.php" method="post" onsubmit="return configFrm.configValidate();">
            <table id="dataTable" cellpadding="0" cellspacing="0">
                <tr><td class="grayHeader" style="padding: 0; width: 100%;" colspan="2"></td></tr>

TABLEHEADER;

    // Iterate through and test and output each system configuration value, performing server/system checks where applicable.
    if (isset($config->rows[0])) {

        foreach ($config->rows as $cfg) {

            switch ($cfg->setting) {

                case 'installed_on':
                    $val = date('l, M j, Y g:i A', strtotime($cfg->value));
                    break;

                case 'updated_on':
                    $val = ($cfg->value == '0000-00-00 00:00:00') ? $never : date('l, M j, Y g:i A', strtotime($cfg->value));
                    break;

                case 'use_ssl_connection':
                    if ($cfg->value == 'Yes') {
                        $yesChecked = "checked=\"checked\" ";
                        $noChecked = "";
                    } else {
                        $yesChecked = "";
                        $noChecked = "checked=\"checked\" ";
                    }
                    $val = "<div class=\"radioDiv\"><input type=\"radio\" class=\"radioBtn\" name=\"use_ssl_connection\" value=\"Yes\" {$yesChecked}/> <span style=\"padding: 0 0 0 5px;\">{$yes}</span> <span class=\"grayPad\">|</span> </div><div class=\"radioDiv\"><input type=\"radio\" class=\"radioBtn\" name=\"use_ssl_connection\" value=\"No\" {$noChecked}/> <span style=\"padding: 0 5px 0 5px;\">{$no}</span></div>";
                    break;

                case 'mobile_access_allowed':
                    if ($cfg->value == 'Yes') {
                        $yesChecked = "checked=\"checked\" ";
                        $noChecked = "";
                    } else {
                        $yesChecked = "";
                        $noChecked = "checked=\"checked\" ";
                    }
                    $val = "<div class=\"radioDiv\"><input type=\"radio\" class=\"radioBtn\" name=\"mobile_access_allowed\" value=\"Yes\" {$yesChecked}/> <span style=\"padding: 0 0 0 5px;\">{$yes}</span> <span class=\"grayPad\">|</span> </div><div class=\"radioDiv\"><input type=\"radio\" class=\"radioBtn\" name=\"mobile_access_allowed\" value=\"No\" {$noChecked}/> <span style=\"padding: 0 5px 0 5px;\">{$no}</span></div>";
                    break;

                case 'multiple_sessions_allowed':
                    if ($cfg->value == 'Yes') {
                        $yesChecked = "checked=\"checked\" ";
                        $noChecked = "";
                    } else {
                        $yesChecked = "";
                        $noChecked = "checked=\"checked\" ";
                    }
                    $val = "<div class=\"radioDiv\"><input type=\"radio\" class=\"radioBtn\" name=\"multiple_sessions_allowed\" value=\"Yes\" {$yesChecked}/> <span style=\"padding: 0 0 0 5px;\">{$yes}</span> <span class=\"grayPad\">|</span> </div><div class=\"radioDiv\"><input type=\"radio\" class=\"radioBtn\" name=\"multiple_sessions_allowed\" value=\"No\" {$noChecked}/> <span style=\"padding: 0 5px 0 5px;\">{$no}</span></div>";
                    break;

                case 'ip_screening':
                    // Check for IP address entry errors.
                    if (isset($sess->ip_error) || isset($sess->ip_allowed_error) || isset($sess->ip_blocked_error)) {
                        if (isset($sess->ip_error)) {
                            $ip_error = "<br />{$sess->ip_error}";
                            $offChecked = "";
                            $onChecked = "checked=\"checked\" ";
                            $ipTableDisplay = "block";
                        } else if (isset($sess->ip_allowed_error) && isset($sess->ip_blocked_error)) {
                            $ip_error = "<br />{$sess->ip_allowed_error}<br />{$sess->ip_blocked_error}";
                            $allowed = $sess->ip_allowed_value;
                            $blocked = $sess->ip_blocked_value;
                            $offChecked = "";
                            $onChecked = "checked=\"checked\" ";
                            $ipTableDisplay = "block";
                        } else if (isset($sess->ip_allowed_error)) {
                            $ip_error = "<br />{$sess->ip_allowed_error}";
                            $allowed = $sess->ip_allowed_value;
                            $blocked = $sess->ip_blocked_value;
                            $offChecked = "";
                            $onChecked = "checked=\"checked\" ";
                            $ipTableDisplay = "block";
                        } else if (isset($sess->ip_blocked_error)) {
                            $ip_error = "<br />{$sess->ip_blocked_error}";
                            $allowed = $sess->ip_allowed_value;
                            $blocked = $sess->ip_blocked_value;
                            $offChecked = "";
                            $onChecked = "checked=\"checked\" ";
                            $ipTableDisplay = "block";
                        } else {
                            $ip_error = '';
                            $allowed = '';
                            $blocked = '';
                            $offChecked = "checked=\"checked\" ";
                            $onChecked = "";
                            $ipTableDisplay = "none";
                        }
                    // Else render current system settings.
                    } else {
                        $ip_error = '';
                        if ($cfg->value == 'Off') {
                            $offChecked = "checked=\"checked\" ";
                            $onChecked = "";
                            $ipTableDisplay = "none";
                        } else {
                            $offChecked = "";
                            $onChecked = "checked=\"checked\" ";
                            $ipTableDisplay = "block";
                        }
                        $cf = new Phire_Table_Config();
                        $allowed = $cf->settings['ip_allowed'];
                        $blocked = $cf->settings['ip_blocked'];
                    }
                    $val = "<div class=\"radioDiv\"><input onclick=\"fx.hide('ipTable');\" type=\"radio\" class=\"radioBtn\" name=\"ip_screening\" value=\"Off\" {$offChecked}/> <span style=\"padding: 0 4px 0 5px;\">{$off}</span> <span class=\"grayPad\">|</span> </div><div class=\"radioDiv\"><input onclick=\"fx.show('ipTable');\" type=\"radio\" class=\"radioBtn\" name=\"ip_screening\" value=\"On\" {$onChecked}/> <span style=\"padding: 0 5px 0 5px;\">{$on}</span></div>";
                    $val .= "<table id=\"ipTable\" style=\"display: {$ipTableDisplay};\"><tr><td class=\"textRight\">&nbsp;</td><td><em>" . $lang->__('You can use wildcards to include subnet groups (i.e., 12.34.56.*) and you can enter multiple IP addresses/groups separated by a comma.') . "</em>{$ip_error}</td></tr><tr><td class=\"textRight\"><strong>" . $lang->__('Allowed:') . "</strong></td><td><input style=\"font-size: 1.0em;\" type=\"text\" name=\"ip_allowed\" size=\"70\" value=\"{$allowed}\" /></td></tr><tr><td class=\"textRight\"><strong>" . $lang->__('Blocked:') . "</strong></td><td><input style=\"font-size: 1.0em;\" type=\"text\" name=\"ip_blocked\" size=\"70\" value=\"{$blocked}\" /></td></tr></table>";
                    break;

                case 'user_verification':
                    if ($cfg->value == 'On') {
                        $onChecked = "checked=\"checked\" ";
                        $offChecked = "";
                    } else {
                        $onChecked = "";
                        $offChecked = "checked=\"checked\" ";
                    }
                    $val = "<div class=\"radioDiv\"><input type=\"radio\" class=\"radioBtn\" name=\"user_verification\" value=\"Off\" {$offChecked}/> <span style=\"padding: 0 4px 0 5px;\">{$off}</span> <span class=\"grayPad\">|</span> </div><div class=\"radioDiv\"><input type=\"radio\" class=\"radioBtn\" name=\"user_verification\" onclick=\"alert('" . addslashes($lang->__("In order for user verification to work properly, both the server's PHP mail function and SMTP mail agent must be configured correctly. If this is not the case, please address this issue as user verification will not function as it should.")) . "');\" value=\"On\" {$onChecked}/> <span style=\"padding: 0 5px 0 5px;\">{$on}</span></div>";
                    break;

                case 'user_password_encoding':
                    $encodingSelect = new Moc10_Form_Element_Select('user_password_encoding', array('SHA1' => 'SHA1', 'MD5' => 'MD5', 'Off' => $none), $cfg->value);
                    $encodingSelect->setAttributes('style', 'font-size: 1.0em;');
                    $val = "\n" . $encodingSelect->render();
                    break;

                case 'table_optimization':
                    if ($cfg->value == 'On') {
                        $onChecked = "checked=\"checked\" ";
                        $offChecked = "";
                    } else {
                        $onChecked = "";
                        $offChecked = "checked=\"checked\" ";
                    }
                    $val = "<div class=\"radioDiv\"><input type=\"radio\" class=\"radioBtn\" name=\"table_optimization\" value=\"Off\" {$offChecked}/> <span style=\"padding: 0 4px 0 5px;\">{$off}</span> <span class=\"grayPad\">|</span> </div><div class=\"radioDiv\"><input type=\"radio\" class=\"radioBtn\" name=\"table_optimization\" value=\"On\" {$onChecked}/> <span style=\"padding: 0 5px 0 5px;\">{$on}</span></div>";

                    $periodSelect = new Moc10_Form_Element_Select('optimization_period', array('Monthly' => $lang->__('Monthly'), 'Weekly' => $lang->__('Weekly'), 'Daily' => $lang->__('Daily')), $config->settings['optimization_period']);
                    $periodSelect->setAttributes('style', 'margin-left: 5px; margin-top: -2px; font-size: 1.0em;');
                    $val .= "\n" . $periodSelect->render();
                    $val .= '<span style="padding-left: 5px;">(' . $lastopt . ' ' . (($config->settings['last_optimization'] == '0000-00-00 00:00:00') ? $never : date('l, M j, Y g:i A', strtotime($config->settings['last_optimization']))) . ')</span>';
                    break;

                case 'failed_login_attempts':
                    $val = "<input style=\"font-size: 1.0em;\" type=\"text\" name=\"failed_login_attempts\" size=\"3\" value=\"{$cfg->value}\" /> <span style=\"padding-left: 5px;\">({$setzero})</span>";
                    break;

                case 'system_notification':
                    $notifyChecks = new Moc10_Form_Element_Checkbox('system_notification', array('Attempted' => $attempted, 'Failed' => $failed, 'Successful' => $successful), explode('|', $cfg->value));
                    $val = "\n" . $notifyChecks->render();
                    break;

                case 'system_notification_filter':
                    $ip_filter_error = (isset($sess->ip_filter_error)) ? "<br />{$sess->ip_filter_error}" : '';
                    $val = (string)Moc10_String::setString($lang->__('Enter any allowed IP addresses or subnet groups (i.e., 12.34.56.*), separated by a comma, that you want to exclude from system notifications (i.e., your home or work IP.)'))->wrap(90, '<br />') . "{$ip_filter_error}<br /><input style=\"margin-top: 5px; font-size: 1.0em;\" type=\"text\" name=\"system_notification_filter\" size=\"70\" value=\"{$cfg->value}\" />";
                    break;

                case 'system_pagination_limit':
                    $val = "<input style=\"font-size: 1.0em;\" type=\"text\" name=\"system_pagination_limit\" size=\"3\" value=\"{$cfg->value}\" /> <span class=\"grayPad\">|</span> <input style=\"font-size: 1.0em;\" type=\"text\" name=\"system_pagination_range\" size=\"3\" value=\"" . $config->settings['system_pagination_range'] . "\" /> <span style=\"padding-left: 5px;\">({$setzero})</span>";
                    break;

                case 'default_editor':
                    $editors = array('Native' => $lang->__('Native'));
                    if (file_exists('../core/scripts/ckeditor')) {
                        $editors['CKEditor'] = 'CKEditor';
                    }
                    if (file_exists('../core/scripts/tinymce')) {
                        $editors['TinyMCE'] = 'TinyMCE';
                    }
                    $editorSelect = new Moc10_Form_Element_Select('default_editor', $editors, $cfg->value);
                    $editorSelect->setAttributes('style', 'font-size: 1.0em;');
                    $val = "\n" . $editorSelect->render();
                    break;

                case 'default_system_template':
                    $val = "<textarea style=\"font-size: 1.0em;\" name=\"default_system_template\" rows=\"8\" cols=\"70\">" . (string)Moc10_String::setString($cfg->value)->strip()->html() . "</textarea>";
                    break;

                case 'default_language':
                    $langs = new Phire_Language();
                    $langAry = $langs->getLanguages();
                    ksort($langAry);
                    $langSelect = new Moc10_Form_Element_Select('default_language', $langAry, $cfg->value);
                    $langSelect->setAttributes('style', 'font-size: 1.0em;');
                    $val = "\n" . $langSelect->render();
                    break;

                case 'system_docroot':
                    if ($cfg->value != $system_docroot) {
                         $val = "<span class=\"error\" style=\"float: right;\">" . $lang->__('Different system document root detected.') . "</span><span class=\"red\">{$cfg->value}</span>";
                         $sync_error_msg = "<span style=\"margin: 0; padding: 0; font-size: 0.85em;\"><span class=\"error\">" . $lang->__('There is a sync error with the software on the server.') . "</span> " . $lang->__('This could be due to a software upgrade or system transfer.') . " " . $lang->__('%1Click here%2 to resolve.', array("<a href=\"./resync.php\">", "</a>")) . "</span>";
                    } else {
                        $val = $cfg->value;
                    }
                    break;

                case 'server_os':
                    if ($cfg->value != $os) {
                         $val = "<span class=\"error\" style=\"float: right;\">" . $lang->__('Different server OS detected.') . "</span><span class=\"red\">{$cfg->value}</span>";
                         $sync_error_msg = "<span style=\"margin: 0; padding: 0; font-size: 0.85em;\"><span class=\"error\">" . $lang->__('There is a sync error with the software on the server.') . "</span> " . $lang->__('This could be due to a software upgrade or system transfer.') . " " . $lang->__('%1Click here%2 to resolve.', array("<a href=\"./resync.php\">", "</a>")) . "</span>";
                    } else {
                        $val = $cfg->value;
                    }

                    break;

                case 'server_software':
                    if ($cfg->value != $server->software) {
                         $val = "<span class=\"error\" style=\"float: right;\">" . $lang->__('Different server software detected.') . "</span><span class=\"red\">{$cfg->value}</span>";
                         $sync_error_msg = "<span style=\"margin: 0; padding: 0; font-size: 0.85em;\"><span class=\"error\">" . $lang->__('There is a sync error with the software on the server.') . "</span> " . $lang->__('This could be due to a software upgrade or system transfer.') . " " . $lang->__('%1Click here%2 to resolve.', array("<a href=\"./resync.php\">", "</a>")) . "</span>";
                    } else {
                        $val = $cfg->value;
                    }
                    break;

                case 'mysql_version':
                    if ($cfg->value != trim(str_ireplace('mysql', '', $mysqlVersionAry[0]))) {
                         $val = "<span class=\"error\" style=\"float: right;\">" . $lang->__('MySQL version %1 detected.', $mysqlVersionAry[0]) . "</span><span class=\"red\">{$cfg->value}</span>";
                         $sync_error_msg = "<span style=\"margin: 0; padding: 0; font-size: 0.85em;\"><span class=\"error\">" . $lang->__('There is a sync error with the software on the server.') . "</span> " . $lang->__('This could be due to a software upgrade or system transfer.') . " " . $lang->__('%1Click here%2 to resolve.', array("<a href=\"./resync.php\">", "</a>")) . "</span>";
                    } else {
                        $val = $cfg->value;
                    }
                    break;

                case 'php_version':
                    if ($cfg->value != $server->php) {
                         $val = "<span class=\"error\" style=\"float: right;\">" . $lang->__('PHP version %1 detected.', $server->php) . "</span><span class=\"red\">{$cfg->value}</span>";
                         $sync_error_msg = "<span style=\"margin: 0; padding: 0; font-size: 0.85em;\"><span class=\"error\">" . $lang->__('There is a sync error with the software on the server.') . "</span> " . $lang->__('This could be due to a software upgrade or system transfer.') . " " . $lang->__('%1Click here%2 to resolve.', array("<a href=\"./resync.php\">", "</a>")) . "</span>";
                    } else {
                        $val = $cfg->value;
                    }
                    break;

                case 'system_version':
                    $val = (isset($sess->update_version)) ? $cfg->value . " (<a href=\"./update.php\">" . $lang->__('Update to') . " v " . $sess->update_version . "</a>?)" : $cfg->value;
                    break;

                default:
                    $val = $cfg->value;

            }

            $setting_name = Moc10_String::setString($cfg->setting)->replace('_', ' ')->upper();
            $setting_name->replace('Docroot', 'Document Root');
            $setting_name->replace('Os', 'Operating System');
            $setting_name->replace('Ssl', 'SSL');
            $setting_name->replace('Mysql', 'MySQL');
            $setting_name->replace('Php', 'PHP');
            $setting_name->replace('Ip ', 'IP ');
            $setting_name->replace('System Pagination Limit', 'System Pagination Limit & Range');
            $setting_name = $lang->__((string)$setting_name);

            $vert = ($cfg->setting == 'default_system_template') ? " vertical-align: top;" : '';

            if (($cfg->setting != 'ip_allowed') && ($cfg->setting != 'ip_blocked') && ($cfg->setting != 'optimization_period') && ($cfg->setting != 'last_optimization') && ($cfg->setting != 'system_pagination_range')) {
                print("                <tr><td style=\"margin: 0; padding: 8px; text-align: left; width: 50%;{$vert}\"><strong>" . $setting_name . "</strong></td><td style=\"margin: 0; padding: 5px; text-align: left; width: 50%;\">{$val}</td></tr>\n");
            }

        }

    } else {

        print("                <tr><td colspan=\"2\" style=\"padding: 25px;\">" . $lang->__('There are currently no configuration settings.') . "</td></tr>\n");

    }

    // Get and output available content types.
    $types = new Phire_Table_ContentTypes();
    $types->findAll();
    $typeList = '';

    // Iterate through each content type.
    if (isset($types->rows[0])) {
        foreach ($types->rows as $typ) {
            $typeList .= $typ->type . " (" . $typ->type_name . ")<br />";
        }
    // Else, print a no result message.
    } else {
        $typeList = $lang->__('No content types available at this time.');
    }

    print("                <tr><td style=\"margin: 0; padding: 8px; text-align: left; width: 50%; vertical-align: top; line-height: 1.5em;\"><strong>" . $lang->__('Available Content Types') . "</strong> <a href=\"./edit-content-types.php\">(" . $lang->__('Edit') . ")</a></td><td style=\"margin: 0; padding: 5px; text-align: left; width: 50%; line-height: 1.5em;\">{$typeList}</td></tr>\n");

    // Get and output available character sets.
    $charsets = new Phire_Table_Charsets();
    $charsets->findAll();
    $charsetList = '';

    // Iterate through each character set.
    if (isset($charsets->rows[0])) {
        foreach ($charsets->rows as $chrset) {
            $charsetList .= $chrset->charset . " (" . $chrset->charset_name . ")<br />";
        }
    // Else, print a no result message.
    } else {
        $charsetList = $lang->__('No character sets available at this time.');
    }

    print("                <tr><td style=\"margin: 0; padding: 8px; text-align: left; width: 50%; vertical-align: top; line-height: 1.5em;\"><strong>" . $lang->__('Available Character Sets') . "</strong> <a href=\"./edit-character-sets.php\">(" . $lang->__('Edit') . ")</a></td><td style=\"margin: 0; padding: 5px; text-align: left; width: 50%; line-height: 1.5em;\">{$charsetList}</td></tr>\n");

    $update = $lang->__('Update');

    // Print the table footer.
    print <<<TABLEFOOTER
            </table>
            <table id="footerTable" cellpadding="0" cellspacing="0"><tr><td>{$sync_error_msg}<input style="float: right;" type="submit" class="submitBtn" value="{$update}" /></td></tr></table>
        </form>
        <script type="text/javascript">
            configFormInit();
        </script>

TABLEFOOTER;

// Else throw a exception/error.
} catch (Exception $e) {

    print("        <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 10px 0;\">" . $e->getMessage() . "</p>\n");

}

?>
